@@ -105,7 +105,8 @@ class BranchHistory_m680x0 : public BranchHistory
 	// info の分岐種別
 	static constexpr uint32 NORMAL		= 0x00000000;	// 通常分岐
 	static constexpr uint32 VECTORJUMP	= 0x40000000;	// ベクタによる分岐
-	static constexpr uint32 SERVICECALL	= 0x80000000;	// IOCS/DOS コール
+	static constexpr uint32 SERVICECALL_HUMAN	= 0x80000000; // IOCS/DOS call
+	static constexpr uint32 SERVICECALL_NETBSD	= 0x80010000; // NetBSD syscall
 	static constexpr uint32 EXCEPTION	= 0xc0000000;	// 例外発生
 
  public:
@@ -122,10 +123,13 @@ class BranchHistory_m680x0 : public BranchHistory
 		return EXCEPTION | vector;
 	}
 	static constexpr uint32 InfoIOCSCall(uint8 num) {
-		return SERVICECALL | num;
+		return SERVICECALL_HUMAN | num;
 	}
 	static constexpr uint32 InfoDOSCall(uint16 ir) {
-		return SERVICECALL | ir;
+		return SERVICECALL_HUMAN | ir;
+	}
+	static constexpr uint32 InfoNetBSDSyscall(uint16 syscall) {
+		return SERVICECALL_NETBSD | syscall;
 	}
 
 	std::string FormatEntry(const BranchEntry& e) override;
