@@ -216,8 +216,6 @@ Debugger::Init()
 		bp.mask = 0xffff0000;
 		bp.md = curmd;
 		AddBreakpoint(bp);
-		// 今登録されている命令ブレークの必要命令長を再計算
-		RecalcInstMask();
 	}
 
 	// 入出力を FILE で扱う
@@ -758,15 +756,11 @@ Debugger::CheckAllBreakpoints(DebuggerMD *md)
 {
 	bool is_break = false;
 	int vector;
-
-	// 命令ごとにクリアする
-	bi_inst = 0;
-	bi_inst_bytes = 0;
+	uint32 inst = 0;
+	int instbytes = 0;
 
 	// 例外はここでローカルにコピーしてから、クリアする。
-	// 厳密には atomic exchange すべきのような。
-	vector = md->bv_vector;
-	md->bv_vector = -1;
+	vector = md->GetAndResetLastVector();
 
 	// 1つの条件でマッチしても(そこでブレークすること自体は確定するのだが)
 	// 残りの他の条件も成立すればカウントを進める必要があるため、
@@ -803,7 +797,15 @@ Debugger::CheckAllBreakpoints(DebuggerMD *md)
 			continue;
 
 		 case BreakpointType::Instruction:
-			if (CheckBreakpointInst(bp)) {
+			if (instbytes < bp.instbytes) {
+				uint64 data = ReadBreakpointInst(bp);
+				if ((int64)data < 0) {
+					continue;
+				}
+				inst = data;
+				instbytes = bp.instbytes;
+			}
+			if ((inst & bp.mask) == bp.inst) {
 				break;
 			}
 			continue;
@@ -854,8 +856,7 @@ Debugger::CheckAllBreakpoints(DebuggerMD *md)
 		 }
 		 case BreakpointType::Instruction:
 			desc += string_format("inst=%0*x",
-				bi_inst_bytes * 2,
-				bi_inst >> ((4 - bi_inst_bytes) * 8));
+				instbytes * 2, inst >> ((4 - instbytes) * 8));
 			break;
 		 default:
 			assert(false);
@@ -874,57 +875,21 @@ Debugger::CheckAllBreakpoints(DebuggerMD *md)
 	return is_break;
 }
 
-// 命令ブレークポイントが成立するか調べる。
-bool
-Debugger::CheckBreakpointInst(breakpoint_t& bp)
+// 命令ブレークポイントの位置の命令を読み込む。
+uint64
+Debugger::ReadBreakpointInst(breakpoint_t& bp)
 {
-	// uint32 bi_inst が現在の PC 位置の命令データ (左詰め)
-	// bi_inst_bytes が読み込んだバイト数(bi_inst の左からの有効バイト数)。
-	// bi_need_bytes が現在のブレークポイントで読み込む必要のあるバイト数。
-
 	busaddr laddr = busaddr(bp.md->GetPC())
 		| BusAddr::Fetch
 		| busaddr::SU(bp.md->IsSuper());
 	DebuggerMemoryStream mem(bp.md, laddr);
-
-	// 必要なバイト数に達するまで読み足す
-	bi_inst = 0;
-	while (bi_inst_bytes < bi_need_bytes) {
-		uint64 data = mem.Read(bp.md->inst_bytes);
-		if ((int64)data < 0) {
-			return false;
-		}
-
-		bi_inst <<= bp.md->inst_bytes * 8;
-		bi_inst |= data;
-		bi_inst_bytes += bp.md->inst_bytes;
+	uint64 inst = mem.Read(bp.instbytes);
+	if ((int64)inst < 0) {
+		return inst;
 	}
-
 	// 左詰めにする
-	bi_inst <<= (4 - bi_inst_bytes) * 8;
-
-	// 必要なバイト数取得できたので比較
-	if ((bi_inst & bp.mask) == bp.inst) {
-		return true;
-	}
-	return false;
-}
-
-// 例外通知 (メイン CPU)
-void
-Debugger::NotifyExceptionMain(int vector)
-{
-	auto md = md_mpu.get();
-	md->bv_vector = vector;
-}
-
-// 例外通知 (XP)。
-// ベクタとして割り込み優先順位 (Intmap*) を使う。
-void
-Debugger::NotifyExceptionXP(int vector)
-{
-	auto md = md_xp.get();
-	md->bv_vector = vector;
+	inst <<= (4 - bp.instbytes) * 8;
+	return (uint32)inst;
 }
 
 // コマンド一覧。
@@ -1090,12 +1055,12 @@ Debugger::HelpListMain = {
 	{ "b*",		"Set/show Breakpoints (Type \"hb\" for details)" },
 	{ "brhist",	"Show branch history" },
 	{ "c/ct",	"Continue" },
-	{ "d/dt/D",	"Disassemble" },
+	{ "d/D",	"Disassemble" },
 	{ "disp",	"Set register group to show" },
 	{ "exhist",	"Show exception history" },
 	{ "help",	"Show this message" },
 	{ "L",		"Set log level" },
-	{ "m/mt/M",	"Memory dump" },
+	{ "m/M",	"Memory dump" },
 	{ "n/nt",	"Step until next instruction (Skip subroutines)" },
 	{ "quit",	"Quit" },
 	{ "r*",		"Show registers (Type \"hr\" for details)" },
@@ -1605,8 +1570,6 @@ Debugger::cmd_b_delete()
 
 	fprintf(cons, "Breakpoint #%d removed.\n", n);
 	bp.type = BreakpointType::Unused;
-	// 今登録されている命令ブレークの必要命令長を再計算
-	RecalcInstMask();
 	return CmdAct::Stay;
 }
 
@@ -1763,6 +1726,7 @@ Debugger::AddBreakInst(const std::string& cpustr, const std::string& argstr,
 		bp.inst <<= 32 - instlen * 4;
 		bp.mask <<= 32 - instlen * 4;
 	}
+	bp.instbytes = instlen / 2;
 
 	// <skip> を取り出す。
 	if (skipstr.empty() == false) {
@@ -1777,9 +1741,6 @@ Debugger::AddBreakInst(const std::string& cpustr, const std::string& argstr,
 		return bi;
 	}
 
-	// 今登録されている命令ブレークの必要命令長を再計算。
-	RecalcInstMask();
-
 	return bi;
 }
 
@@ -1822,10 +1783,10 @@ Debugger::cmd_bv()
 	fprintf(cons, "Breakpoint #%d added.\n", bi);
 
 	// この CPU 側に、すでに来ている例外をクリア。
-	// ブレークポイント設定の有無に関わらず例外が起きたら CPU 側から常に
-	// 通知されている。これをクリアするのは CheckAllBreakpoints() で、これは
+	// ブレークポイント設定の有無に関わらず例外が起きたら CPU 側は常に
+	// 記録している。これをクリアするのは CheckAllBreakpoints() で、これは
 	// 命令間(命令前)に呼ばれるやつ、なのでこうなる。
-	// 1. 例外が起きると md->bv_vector がセットされる
+	// 1. 例外が起きると md->cpu->last_vector がセットされる
 	// 2. 例外ブレークポイントを設定していないとこれがクリアされない
 	// 3. bv コマンドで例外ブレークを新たに設定すると、次の命令境界で
 	//    1.のベクタが反応してしまう。
@@ -1836,7 +1797,7 @@ Debugger::cmd_bv()
 	// bp.md は AddBreakpoint() で bpoint 登録時にセットされるので
 	// インデックスから bp をもう一度読み込む。
 	auto bp = bpoint[bi];
-	bp.md->bv_vector = -1;
+	bp.md->GetAndResetLastVector();
 
 	return CmdAct::Stay;
 }
@@ -2147,9 +2108,6 @@ Debugger::cmd_bx()
 	}
 	fprintf(cons, "All breakpoints are removed.\n");
 
-	// 今登録されている命令ブレークの必要命令長を再計算
-	RecalcInstMask();
-
 	return CmdAct::Stay;
 }
 
@@ -2209,39 +2167,6 @@ Debugger::AddBreakpoint(const breakpoint_t& new_bp)
 	return -1;
 }
 
-// すべての命令ブレークのマスクのうち最長のものを再計算する。
-// 命令ブレークポイントの追加/削除のたびに呼び出すこと。
-void
-Debugger::RecalcInstMask()
-{
-	uint32 mask;
-	bi_need_bytes = 0;
-
-	// 登録されている命令ブレークの最長マスクを求める
-	mask = 0;
-	for (const auto& bp : bpoint) {
-		if (bp.type == BreakpointType::Instruction) {
-			mask |= bp.mask;
-		}
-	}
-
-	// mask の Number of Trailing Zero を求める。
-	// (x & -x) で x の最も下の立ってるビットだけを立てる、
-	// (x & -x) -1 でそれより下の全ビットを立てる、
-	// それを popcount で数えるので、$fffffff0 なら ntz = 4 になる。
-	int ntz = __builtin_popcount((mask & -(int32)mask) - 1);
-	// 上位側から数えたマスクに必要なビット数
-	int mlen = 32 - ntz;
-	// 命令語単位に切り上げる
-	mlen = roundup(mlen, curmd->inst_bytes * 8);
-	// バイト数に変換
-	mlen /= 8;
-
-	if (mlen > bi_need_bytes) {
-		bi_need_bytes = mlen;
-	}
-}
-
 // ブランチ履歴、例外履歴表示
 // brhist [<maxlines>]
 // exhist [<maxlines>]
@@ -2517,20 +2442,7 @@ Debugger::CmdAct
 Debugger::cmd_z()
 {
 	// 次のアドレスを求める。
-	if (curmd->inst_bytes_fixed) {
-		// 固定長命令
-		step_addr = curmd->GetPC() + curmd->inst_bytes_fixed;
-	} else {
-		// 可変長なら逆アセンブルしてみるしか。
-
-		busaddr laddr = busaddr(curmd->GetPC())
-			| BusAddr::Fetch
-			| busaddr::SU(curmd->IsSuper());
-		DebuggerMemoryStream mem(curmd, laddr);
-		// XXX 失敗したらどうすべ
-		curmd->Disassemble(mem);
-		step_addr = mem.laddr.Addr();
-	}
+	step_addr = curmd->GetNextPC();
 	step_type = StepType::Addr;
 	step_md = curmd;
 
@@ -2834,20 +2746,7 @@ Debugger::SetNBreakpoint()
 	// 命令がサブルーチンやトラップなどステップインできる命令か。
 	if (curmd->IsOpStepIn(mem)) {
 		// この次の命令にブレークをかける
-		if (curmd->inst_bytes_fixed != 0) {
-			// 固定長命令
-			step_addr = mem.laddr.Addr();
-		} else {
-			// 可変長なら逆アセンブルしてみるしか。
-			// 表示用文字列は作る必要ないけど、処理分けるのも手間だし
-			// ここは人間がコマンド打った時しかこないので気にしない。
-
-			// IsOpStepIn() が mem を進めるので戻す。
-			mem.ResetAddr(curmd->GetPC());
-			// XXX 失敗したらどうすべ
-			curmd->Disassemble(mem);
-			step_addr = mem.laddr.Addr();
-		}
+		step_addr = curmd->GetNextPC();
 	} else {
 		// そうでなければ1命令進める。
 		step_addr = (int64)-1;
@@ -3207,11 +3106,24 @@ DebuggerMD::DebuggerMD(Debugger *parent_, CPUArch arch_)
 {
 	parent = parent_;
 	arch = arch_;
-
-	bv_vector = -1;
 }
 
 // デストラクタ
 DebuggerMD::~DebuggerMD()
 {
 }
+
+// 現在の命令の直後の命令アドレスを返す。
+// 命令が可変長のアーキテクチャなら逆アセンブルしてみるしかない。
+// 命令が固定長のアーキテクチャはオーバーライドして解決のこと。
+uint32
+DebuggerMD::GetNextPC()
+{
+	busaddr laddr = busaddr(GetPC())
+		| BusAddr::Fetch
+		| busaddr::SU(IsSuper());
+	DebuggerMemoryStream mem(this, laddr);
+	// XXX 失敗したらどうすべ
+	Disassemble(mem);
+	return mem.laddr.Addr();
+}
