@@ -72,6 +72,7 @@ class Debugger : public ThreadDevice
 			struct {
 				uint32 inst;	// 命令ワード
 				uint32 mask;	// マスク
+				int instbytes;	// 命令バイト数
 			};
 		};
 
@@ -108,8 +109,6 @@ class Debugger : public ThreadDevice
 
 	void ExecMain()	{ Exec(md_mpu.get()); }
 	void ExecXP()	{ Exec(md_xp.get()); }
-	void NotifyExceptionMain(int vector);
-	void NotifyExceptionXP(int vector);
 
 	// MPU トレースが必要なら true を返す
 	bool IsTrace() const;
@@ -130,7 +129,7 @@ class Debugger : public ThreadDevice
 	void Exec(DebuggerMD *);
 	CmdAct Command();
 	bool CheckAllBreakpoints(DebuggerMD *);
-	bool CheckBreakpointInst(breakpoint_t&);
+	uint64 ReadBreakpointInst(breakpoint_t&);
 	void ParseCmdbuf();
 	// コマンド名は大文字小文字を区別する関係でスネークスタイル。
 	CmdAct cmd_b();
@@ -180,7 +179,6 @@ class Debugger : public ThreadDevice
 	int AddBreakVector(const std::string& cpustr, const std::string& vecstr,
 		const std::string& skipstr, std::string *errstr);
 	int AddBreakpoint(const breakpoint_t&);
-	void RecalcInstMask();
 	bool GetAddr(busaddr *addr, bool);
 	CmdAct cmd_d_common(busaddr access_mode);
 	CmdAct cmd_hist_common(BranchHistory& hist);
@@ -236,9 +234,6 @@ class Debugger : public ThreadDevice
 
 	uint32 pc {};
 	std::array<breakpoint_t, MAX_BREAKPOINTS> bpoint {};
-	uint32 bi_inst {};
-	int bi_inst_bytes {};
-	int bi_need_bytes {};
 	uint64 ct_timespan {};
 	busaddr d_last_addr {};
 	busaddr m_last_addr {};
@@ -281,6 +276,6 @@ class Debugger : public ThreadDevice
 	static std::vector<cmddef_t> cmdtable;
 };
 
-static inline Debugger *GetDebugger() {
+inline Debugger *GetDebugger() {
 	return Object::GetObject<Debugger>(OBJ_DEBUGGER);
 }
