@@ -26,6 +26,9 @@ class DebuggerMD_hd64180 : public DebuggerMD
 	bool MMUEnabled() const override	{ return true; }
 	busaddr TranslateAddr(busaddr laddr) const override;
 	uint32 GetPC() const override { return cpu->reg.pc; }
+	int32 GetAndResetLastVector() override {
+		return cpu->GetAndResetLastVector();
+	}
 
 	void SetStepOut() override;
 	bool IsStepOut() const override;
