@@ -26,7 +26,6 @@ DebuggerMD_m680x0::DebuggerMD_m680x0(Debugger *parent_)
 
 	// 機種依存変数
 	inst_bytes = 2;
-	inst_bytes_fixed = 0;
 	lasize = 32;
 	pasize = 32;
 	name = "mpu";
@@ -256,9 +255,15 @@ DebuggerMD_m680x0::GetRegAddr(const char *name) const
 	uint32 addr;
 
 	if ((*name | 0x20) == 'a') {
+		if (name[1] < '0' || name[1] > '7') {
+			return (uint64)-1;
+		}
 		addr = cpu->reg.A[name[1] - '0'];
 
 	} else if ((*name | 0x20) == 'd') {
+		if (name[1] < '0' || name[1] > '7') {
+			return (uint64)-1;
+		}
 		addr = cpu->reg.D[name[1] - '0'];
 
 	} else if (strcmp(name, "sp") == 0) {
