@@ -27,6 +27,9 @@ class DebuggerMD_m680x0 : public DebuggerMD
 	busaddr TranslateAddr(busaddr laddr) const override;
 
 	uint32 GetPC() const override { return cpu->reg.pc; }
+	int32 GetAndResetLastVector() override {
+		return cpu->GetAndResetLastVector();
+	}
 
 	void SetStepOut() override;
 	bool IsStepOut() const override;
