@@ -45,6 +45,12 @@ class DebuggerMD
 	// 現在の命令先頭アドレスを返す
 	virtual uint32 GetPC() const = 0;
 
+	// 現在の命令の直後の命令アドレスを返す。
+	virtual uint32 GetNextPC();
+
+	// 最後に発生したベクタを取得し、リセットする
+	virtual int32 GetAndResetLastVector() = 0;
+
 	// ステップアウトを設定する
 	virtual void SetStepOut() = 0;
 	// ステップアウトなら true を返す
@@ -95,12 +101,6 @@ class DebuggerMD
 
 	// 最短の1命令のバイト数
 	uint inst_bytes {};
-	// 命令が固定長ならそのバイト数、可変長なら 0
-	uint inst_bytes_fixed {};
-
-	// 例外ブレーク。
-	// 機種固有ではないが main と xp でそれぞれに必要なので、ここに持っておく。
-	int bv_vector {};
 
  protected:
 	Debugger *parent {};	// 親クラス
