@@ -18,6 +18,33 @@
 <div class="main1">
 <dl>
 
+<dt>1.6.3 (2025/11/25)
+<dd><ul>
+<li>m68k(Fix): 68030 テーブルサーチのページアドレスマスクを修正。
+ <q>Fix page address mask in several places on 68030 table search.</q>
+<li>m68k(Update): 68030 ATC をオリジナル準拠 (FC 混合22エントリ) に戻す。
+この2件で現在の NetBSD/m68k newpmap カーネルが起動します
+(実際の原因は NetBSD カーネルのバグのはずですが)。
+ <q>Revert 68030 ATC to original-compliant behavior (FC-mixed 22-entries).
+ These two fixes make current NetBSD/m68k newpmap kernel bootable
+ (though the actual cause should be a bug in the NetBSD kernel).</q>
+<li>m68k(Fix): 68040 の PFLUSH* 命令のグローバルエントリの削除条件が逆だったのを修正。
+ <q>Fix inverted condition in PFLUSH* for deleting global entries on 68040.</q>
+<li>GUI(New): 68030, 68040 のページテーブルモニタを実装。
+ <q>Implement 68030 and 68040 page table monitor window.</q>
+<li>GUI(Fix): ログウィンドウを伸ばすと不正終了していたのを修正。
+ <q>Fix an abnormal termination when the log window is stretched.</q>
+<li>debugger(Fix): 命令ブレークポイントが効かないケースがあったのを修正。
+ <q>Fix an issue where instruction breakpoints might not work.</q>
+<li>debugger(Update): 例外履歴に NetBSD/m68k システムコール番号を表示。
+ <q>Show NetBSD/m68k system call number for exception history.</q>
+<li>build(Fix): ver1.6.0 以降 x86_64, i386 以外でビルドエラーになっていたのを修正。
+ <q>Fix a build error on platforms other than x86_64 and i386 after ver 1.6.0.</q>
+<li>vm(Update): 注: 次リリース向けの作業中だった時間軸周りの変更が多数入っていますが、動作は変わっていないはずです。
+<q>Note: It includes a lot of time axis-related changes that were in the
+work for the next release, but no functional changes are expected.</q>
+</ul><p>
+
 <dt>1.6.2 (2025/11/11)
 <dd><ul>
 <li>m68k(Fix): 68881 の FRESTORE 命令がヌルステートフレームの長さフィールドを無視するよう修正。
