@@ -51,6 +51,6 @@ Driver::Dispatch(int udata)
 
 // モニタ (ドライバ依存情報のみ)
 void
-Driver::MonitorUpdateMD(TextScreen& screen, int y)
+Driver::MonitorScreenMD(TextScreen& screen, int y)
 {
 }
