@@ -36,7 +36,7 @@ class Driver : public Object
 	// モニタのうちドライバ依存部分の情報を書き出す。
 	// screen のうち y行目から2行のみがドライバ依存部分なので
 	// ここだけ書き出すこと。不要なら書き出さなくてよい。Clear() しないこと。
-	virtual void MonitorUpdateMD(TextScreen& screen, int y);
+	virtual void MonitorScreenMD(TextScreen& screen, int y);
 
 	// ドライバ名を取得。
 	const std::string& GetDriverName() const { return drivername; }
