@@ -132,7 +132,7 @@ HostNetDevice::HostNetDevice(Device *parent_, uint n,
 	assert(ihwaddrfilter);
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_HOSTNET(n), this);
-	monitor->func = ToMonitorCallback(&HostNetDevice::MonitorUpdate);
+	monitor->SetCallback(&HostNetDevice::MonitorScreen);
 	monitor->SetSize(48, 24);
 
 #if defined(HAVE_HOSTNET_SLIRP)
@@ -645,7 +645,7 @@ HostNetDevice::CountTXUnsupp(size_t bytes)
 
 // モニタ
 void
-HostNetDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+HostNetDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	screen.Clear();
 
@@ -655,7 +655,7 @@ HostNetDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 		screen.Print(0, 1, "HostNet Driver: %s",
 			driver->GetDriverName().c_str());
 		// 次の2行はドライバ依存情報
-		driver->MonitorUpdateMD(screen, 2);
+		driver->MonitorScreenMD(screen, 2);
 	}
 
 	// 01234567890123456
