@@ -852,6 +852,6 @@ HostWindrv::SetFileTime(Windrv::FCB *fcb, uint32 datetime)
 /*static*/ uint64
 HostWindrv::timespec2nsec(const struct timespec& ts)
 {
-	return (uint64)ts.tv_sec * 1000'000'000 + (uint64)ts.tv_nsec;
+	return sec_to_nsec(ts.tv_sec) + ts.tv_nsec;
 }
 #endif
