@@ -24,7 +24,7 @@ Logger::Logger()
 	ClearAlias();
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_LOG, this);
-	monitor->func = ToMonitorCallback(&Logger::MonitorUpdate);
+	monitor->SetCallback(&Logger::MonitorScreen);
 	monitor->SetSize(80, 40);	// 初期サイズは適当
 }
 
@@ -289,7 +289,7 @@ Logger::ResizeCol(int newcol)
 // userdata = 1 なら1行古いほうに遡った状態、となる。
 // screen.userdata + screen の行数が maxlines を超えてはいけない。
 void
-Logger::MonitorUpdate(Monitor *, TextScreen& screen)
+Logger::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	assertmsg(screen.userdata + screen.GetRow() <= maxlines,
 		"userdata=%" PRIu64 " row=%d maxlines=%d",
