@@ -33,15 +33,6 @@ class NetDriver : public Driver
 	// パケットを外部に送信する。
 	virtual void Write(const void *buf, int buflen) = 0;
 
-	// InitDriver() 中の(主に最後の)エラーメッセージ。
-	// NetDriver は複数を順番に試す場合もあるし、全部エラーになっても終了する
-	// かどうかは設定によるので、各ドライバはエラーが発生しても各自で warnx に
-	// よる表示はせず、ここにエラーメッセージをセットする。必要になった時点で
-	// HostNetDevice が最後の一つを warnx() で表示する。
-	// なお、おそらくそれだけでは大抵何も分からないのでこれとは別に
-	// ログレベル 1 で putmsg() は充実させておくこと。
-	std::string errmsg {};
-
  protected:
 	// ifup/ifdown スクリプト実行
 	bool Run_ifup();
@@ -52,7 +43,7 @@ class NetDriver : public Driver
 	// デバイスディスクリプタ。
 	// ディスクリプタを持つというのは共通なのでディスクリプタはここに置くが
 	// これを Open(), Close() するのはあくまで継承側の仕事で、こちらでは
-	// 初期化と IsOpen() だけ受け持つ。ちょっと責任分解点が気持ち悪いけど。
+	// 初期化と IsOpen() だけ受け持つ。ちょっと責任分界点が気持ち悪いけど。
 	autofd fd {};
 
  private:
