@@ -768,7 +768,7 @@ SlirpThread::ThreadRun()
 
 	while (exit_requested == false) {
 		// タイマー処理。
-		int64 cur_msec = ClockGetNsCB() / 1000'000;
+		int64 cur_msec = nsec_to_msec(ClockGetNsCB());
 		for (auto it = timerlist.begin(); it != timerlist.end(); ) {
 			SlirpTimer *timer = *it;
 			if (timer->expire_msec <= cur_msec) {
