@@ -314,7 +314,7 @@ NetDriverTap::Close()
 
 // モニタ (ドライバ依存情報のみ)
 void
-NetDriverTap::MonitorUpdateMD(TextScreen& screen, int y)
+NetDriverTap::MonitorScreenMD(TextScreen& screen, int y)
 {
 	screen.Print(0, y++, "Device   : %s", devpath.c_str());
 	screen.Print(0, y++, "Interface: %s", ifname.c_str());
