@@ -44,7 +44,7 @@ SoundDriverALSA::InitDriver(bool startup)
 		return false;
 	}
 
-	uint period = freq * Sound::BLK_NSEC / 1_sec;
+	uint period = freq * Sound::BLK_TSEC / 1_sec;
 
 	snd_pcm_hw_params_malloc(&params);
 	snd_pcm_hw_params_any(pcm, params);
