@@ -44,7 +44,7 @@ SoundDriverSndIO::InitDriver(bool startup)
 	param.sig = 1;
 	param.le = SIO_LE_NATIVE;
 	param.pchan = Sound::NCHAN;
-	param.appbufsz = freq * Sound::BLK_NSEC / 1_sec;
+	param.appbufsz = freq * Sound::BLK_TSEC / 1_sec;
 	if (sio_setpar(sio, &param) != 1) {
 		warn("%s: sio_set_par() failed", __method__);
 		sio_close(sio);
