@@ -23,7 +23,7 @@ class SoundDriverWav : public SoundDriver
 
 	void Write(const int16 *) override;
 
-	void MonitorUpdateMD(TextScreen&, int y) override;
+	void MonitorScreenMD(TextScreen&, int y) override;
 
  private:
 	bool OpenWav();
