@@ -10,11 +10,13 @@
 
 #pragma once
 
-#include "object.h"
+#include "header.h"
+#include <vector>
 
 class Config;
 class Logger;
 class MonitorManager;
+class Object;
 class ThreadManager;
 class UIMessage;
 class VM;
@@ -43,7 +45,7 @@ enum class VMCap : uint32 {
 	M88K	= VMCap::LUNA88K,
 	ALL		= 0xffffffff,
 };
-static inline VMCap operator|(VMCap a, VMCap b) {
+inline VMCap operator|(VMCap a, VMCap b) {
 	return static_cast<VMCap>(static_cast<uint32>(a) | static_cast<uint32>(b));
 }
 
