@@ -45,7 +45,7 @@ class Stopwatch
 	}
 
 	// 経過時間を nsec で返す
-	uint64 Elapsed() const {
+	uint64 Elapsed_nsec() const {
 		using namespace std::chrono;
 		if (running) {
 			return duration_cast<nanoseconds>(Now() - epoch + total).count();
