@@ -441,12 +441,12 @@ MPU68030Device::read_single(busdata bd, uint32 readmask, uint32 opermask)
 		if (portsize == 2) {
 			uint32 off2 = offset & 2;
 			data |= bd.Data() << ((2 - off2) * 8);
-			set = 0x3 << (2 - off2);
+			set = 0x3U << (2 - off2);
 			// 次の読み込みにむけて更新。
 			offset = 2 - off2;
 		} else {
 			data |= bd.Data() << ((3 - offset) * 8);
-			set = 0x1 << (3 - offset);
+			set = 0x1U << (3 - offset);
 			// 次の読み込みにむけて更新。
 			offset = (offset + 1) & 3;
 		}
@@ -836,7 +836,7 @@ m68030Cache::CalcStat()
 	// 前回から今回までの間に disable になったのなら有効な値がある。
 	if (__predict_true(enable || total_read != 0)) {
 		// ここはロックする。
-		std::unique_lock<std::mutex> lock(hist_mtx);
+		std::lock_guard<std::mutex> lock(hist_mtx);
 		hist.EnqueueForce(s);
 	}
 }
