@@ -187,28 +187,14 @@ MPU68030Device::SetTT(int n, uint32 data)
 	uint32 sbase;
 	uint32 smask;
 
+#if defined(M68030_CUSTOM_ATC)
 	// ハッシュから TT#n の成分を一旦クリアする。
 	if (mmu_tt[n].e) {
 		// 変更前の TT#n にマッチして、現在の TT#(1-n) にマッチしない
 		// アドレスブロックに対応する 4096 エントリをクリア。
-		for (int fc = 1; fc <= 6; fc++) {
-			auto *table = atc.fctables[fc];
-			if (table) {
-				busaddr laddr = busaddr(0) | busaddr::FC(fc);
-				for (int i = 0; i < 256; i++) {
-					// XXX R/W は?
-					if (mmu_tt[n].Match(laddr) &&
-						mmu_tt[1 - n].Match(laddr) == false)
-					{
-						uint32 baseidx = i << (24 - 12);
-						memset(&table->hash[baseidx],
-							m68030ATCTable::HASH_NONE, 4096);
-					}
-					laddr += 0x0100'0000;
-				}
-			}
-		}
+		atc.UnsetFromHash(mmu_tt[n], mmu_tt[1 - n]);
 	}
+#endif
 
 	// マスクしてレジスタイメージにセット
 	reg.tt[n] = data & m68030TT::MASK;
@@ -269,26 +255,14 @@ MPU68030Device::SetTT(int n, uint32 data)
 	mmu_tt[n].base = lbase | (((uint64)sbase) << 32);
 	mmu_tt[n].mask = lmask | (((uint64)smask) << 32);
 
+#if defined(M68030_CUSTOM_ATC)
 	// 更新後にこの TT が有効ならハッシュも更新。
 	if (mmu_tt[n].e) {
 		// この TT#n にマッチするアドレスブロックに対応する 4096 エントリを
 		// TT 印にする。
-		for (uint fc = 1; fc <= 6; fc++) {
-			auto *table = atc.fctables[fc];
-			if (table) {
-				busaddr laddr = busaddr(0) | busaddr::FC(fc);
-				for (uint i = 0; i < 256; i++) {
-					// XXX R/W は?
-					if (mmu_tt[n].Match(laddr)) {
-						uint32 baseidx = i << (24 - 12);
-						memset(&table->hash[baseidx],
-							m68030ATCTable::HASH_TT, 4096);
-					}
-					laddr += 0x0100'0000;
-				}
-			}
-		}
+		atc.SetToHash(mmu_tt[n]);
 	}
+#endif
 
 	mmu_enable_changed();
 }
@@ -330,11 +304,10 @@ MPU68030Device::SetTC(uint32 data)
 	// マスクをあらかじめ用意しておく
 	mmu_tc.MakeMask();
 
-	// ATC でも PS を覚えておく必要がある。
-	for (int i = 0; i < countof(atc.tables); i++) {
-		auto *table = atc.tables[i].get();
-		table->ps4k = mmu_tc.ps - 12;
-	}
+#if defined(M68030_CUSTOM_ATC)
+	// ハッシュのため ATC 側でも PS を覚えておく必要がある。
+	atc.SetPS(mmu_tc.ps);
+#endif
 
 	// TC:E が変更されていればスイッチ更新
 	mmu_enable_changed();
@@ -444,15 +417,19 @@ m68030ATC::m68030ATC(MPU68030Device *cpu_)
 {
 	cpu = cpu_;
 
-	tables[0].reset(new m68030ATCTable(cpu, 1));
-	tables[1].reset(new m68030ATCTable(cpu, 2));
-	tables[2].reset(new m68030ATCTable(cpu, 5));
-	tables[3].reset(new m68030ATCTable(cpu, 6));
+#if defined(M68030_CUSTOM_ATC)
+	tables[0].reset(new m68030ATCTable_Custom(cpu, 1));
+	tables[1].reset(new m68030ATCTable_Custom(cpu, 2));
+	tables[2].reset(new m68030ATCTable_Custom(cpu, 5));
+	tables[3].reset(new m68030ATCTable_Custom(cpu, 6));
 
 	fctables[1] = tables[0].get();
 	fctables[2] = tables[1].get();
 	fctables[5] = tables[2].get();
 	fctables[6] = tables[3].get();
+#else
+	table.reset(new m68030ATCTable_Motorola(cpu));
+#endif
 }
 
 // デストラクタ
@@ -466,20 +443,101 @@ void
 m68030ATC::SetLogLevel(int loglevel_)
 {
 	loglevel = loglevel_;
+#if defined(M68030_CUSTOM_ATC)
 	for (int i = 0; i < countof(tables); i++) {
 		auto *table = tables[i].get();
 		table->loglevel = loglevel_;
 	}
+#else
+	table->loglevel = loglevel_;
+#endif
 }
 
+// 統計情報をリセットする。
+void
+m68030ATC::ResetStat()
+{
+#if defined(M68030_CUSTOM_ATC)
+	for (int i = 0; i < countof(tables); i++) {
+		auto *table = tables[i].get();
+		table->atcstat = {};
+		std::lock_guard<std::mutex> lock(table->atchist_mtx);
+		table->atchist.Clear();
+		table->atchist_tt_once_hit = false;
+	}
+#else
+	table->atcstat = {};
+	table->stat_atchit.fill(0);
+#endif
+}
+
+#if defined(M68030_CUSTOM_ATC)
+// ハッシュの、この tt にマッチするブロックを TT 印にする。
+void
+m68030ATC::SetToHash(const m68030TT& tt)
+{
+	for (uint fc = 1; fc <= 6; fc++) {
+		auto *table = fctables[fc];
+		if (table) {
+			busaddr laddr = busaddr(0) | busaddr::FC(fc);
+			for (uint i = 0; i < 256; i++) {
+				// XXX R/W は?
+				if (tt.Match(laddr)) {
+					uint32 baseidx = i << (24 - 12);
+					memset(&table->hash[baseidx],
+						m68030ATCTable_Custom::HASH_TT, 4096);
+				}
+				laddr += 0x0100'0000;
+			}
+		}
+	}
+}
+// current TT にマッチして、other TT にマッチしない部分をハッシュから消す。
+void
+m68030ATC::UnsetFromHash(const m68030TT& current, const m68030TT& other)
+{
+	for (int fc = 1; fc <= 6; fc++) {
+		auto *table = fctables[fc];
+		if (table) {
+			busaddr laddr = busaddr(0) | busaddr::FC(fc);
+			for (int i = 0; i < 256; i++) {
+				// XXX R/W は?
+				if (current.Match(laddr) && other.Match(laddr) == false) {
+					uint32 baseidx = i << (24 - 12);
+					memset(&table->hash[baseidx],
+						m68030ATCTable_Custom::HASH_NONE, 4096);
+				}
+				laddr += 0x0100'0000;
+			}
+		}
+	}
+}
+
+// ハッシュのため、ページサイズを ATC 側でも持っておく必要がある。
+void
+m68030ATC::SetPS(uint32 ps)
+{
+	for (uint fc = 1; fc <= 6; fc++) {
+		auto *table = fctables[fc];
+		if (table) {
+			table->ps4k = ps - 12;
+		}
+	}
+}
+#endif // M68030_CUSTOM_ATC
+
 // ATC をすべてフラッシュする。命令からコールされる
 void
 m68030ATC::flush()
 {
+#if defined(M68030_CUSTOM_ATC)
 	for (int i = 0; i < countof(tables); i++) {
 		auto *table = tables[i].get();
 		table->Flush();
 	}
+#else
+	table->Flush();
+#endif
 }
 
 // ATC の fc, mask が一致するエントリをフラッシュする。
@@ -487,6 +545,7 @@ m68030ATC::flush()
 void
 m68030ATC::flush(uint32 fc, uint32 mask)
 {
+#if defined(M68030_CUSTOM_ATC)
 	for (uint i = 1; i <= 6; i++) {
 		if (((i ^ fc) & mask) == 0) {
 			// FC が一致したテーブルを全フラッシュ
@@ -496,6 +555,9 @@ m68030ATC::flush(uint32 fc, uint32 mask)
 			}
 		}
 	}
+#else
+	table->Flush(fc, mask);
+#endif
 }
 
 // ATC の fc, mask, addr が一致するエントリをフラッシュする。
@@ -503,6 +565,7 @@ m68030ATC::flush(uint32 fc, uint32 mask)
 void
 m68030ATC::flush(uint32 fc, uint32 mask, uint32 addr)
 {
+#if defined(M68030_CUSTOM_ATC)
 	for (uint i = 1; i <= 6; i++) {
 		if (((i ^ fc) & mask) == 0) {
 			// FC が一致したテーブルから addr が一致したエントリをフラッシュ
@@ -512,6 +575,9 @@ m68030ATC::flush(uint32 fc, uint32 mask, uint32 addr)
 			}
 		}
 	}
+#else
+	table->Flush(fc, mask, addr);
+#endif
 }
 
 
@@ -519,6 +585,8 @@ m68030ATC::flush(uint32 fc, uint32 mask, uint32 addr)
 // ATC テーブル
 //
 
+#if defined(M68030_CUSTOM_ATC)
+
 // アドレス変換の本来のフローはこんな感じだが、
 //
 //  if (TT*.E || TC.E) {
@@ -561,7 +629,7 @@ m68030ATC::flush(uint32 fc, uint32 mask, uint32 addr)
 // フラッシュが起きるんじゃないかな…
 
 // コンストラクタ
-m68030ATCTable::m68030ATCTable(MPU68030Device *cpu_, uint fc_)
+m68030ATCTable_Custom::m68030ATCTable_Custom(MPU68030Device *cpu_, uint fc_)
 {
 	cpu = cpu_;
 	fc = fc_;
@@ -573,13 +641,13 @@ m68030ATCTable::m68030ATCTable(MPU68030Device *cpu_, uint fc_)
 }
 
 // デストラクタ
-m68030ATCTable::~m68030ATCTable()
+m68030ATCTable_Custom::~m68030ATCTable_Custom()
 {
 }
 
 // この ATC テーブルのエントリをすべてフラッシュする。
 void
-m68030ATCTable::Flush()
+m68030ATCTable_Custom::Flush()
 {
 	for (int i = 0; i < LINES; i++) {
 		Invalidate(&line[i]);
@@ -590,7 +658,7 @@ m68030ATCTable::Flush()
 
 // この ATC テーブルから addr が一致するエントリをすべてフラッシュする。
 void
-m68030ATCTable::Flush(uint32 addr)
+m68030ATCTable_Custom::Flush(uint32 addr)
 {
 	for (int i = 0; i < LINES; i++) {
 		m68030ATCLine *a = &line[i];
@@ -602,7 +670,7 @@ m68030ATCTable::Flush(uint32 addr)
 
 // この要素を先頭に移動。
 inline void
-m68030ATCTable::MoveHead(m68030ATCLine *a)
+m68030ATCTable_Custom::MoveHead(m68030ATCLine *a)
 {
 	a->age = ++latest_age;
 
@@ -617,7 +685,7 @@ m68030ATCTable::MoveHead(m68030ATCLine *a)
 
 // このテーブルのうち最も古い要素を差し出す。
 m68030ATCLine *
-m68030ATCTable::RemoveTail()
+m68030ATCTable_Custom::RemoveTail()
 {
 	m68030ATCLine *a = NULL;
 	uint32 min = (uint32)~0;
@@ -645,7 +713,7 @@ m68030ATCTable::RemoveTail()
 
 // a からハッシュを作成する。
 void
-m68030ATCTable::MakeHash(const m68030ATCLine *a)
+m68030ATCTable_Custom::MakeHash(const m68030ATCLine *a)
 {
 	uint32 addr4k = a->GetLAddr() >> 12;
 	int idx = a - &line[0];
@@ -663,7 +731,7 @@ m68030ATCTable::MakeHash(const m68030ATCLine *a)
 
 // ATC a を無効にする。すでに無効なら何もしない。
 void
-m68030ATCTable::Invalidate(m68030ATCLine *a)
+m68030ATCTable_Custom::Invalidate(m68030ATCLine *a)
 {
 	if (a->IsValid()) {
 		// 有効ならハッシュから削除。
@@ -687,7 +755,7 @@ m68030ATCTable::Invalidate(m68030ATCLine *a)
 
 // PS<4KB の場合に aa が抜けることでこの addr4k の枠が空けばハッシュから削除。
 void
-m68030ATCTable::InvalidateSub(const m68030ATCLine *aa)
+m68030ATCTable_Custom::InvalidateSub(const m68030ATCLine *aa)
 {
 	const uint32 MASK_4K = 0xfffff000 | m68030ATCLine::INVALID;
 	uint32 target_laddr = aa->GetTag() & MASK_4K;
@@ -714,7 +782,7 @@ m68030ATCTable::InvalidateSub(const m68030ATCLine *aa)
 
 // laddr を ATC から探す。見つからなければ NULL を返す。
 m68030ATCLine *
-m68030ATCTable::FindSub(const busaddr laddr)
+m68030ATCTable_Custom::FindSub(const busaddr laddr)
 {
 	uint32 addr = laddr.Addr() & cpu->mmu_tc.lmask;
 
@@ -731,7 +799,7 @@ m68030ATCTable::FindSub(const busaddr laddr)
 // テーブルサーチを行う。
 // テーブルという用語がぶつかっているので MMU Search にしてある。
 m68030ATCLine *
-m68030ATCTable::MMUSearch(busaddr laddr)
+m68030ATCTable_Custom::MMUSearch(busaddr laddr)
 {
 	m68030ATCLine *a = RemoveTail();
 	a->tag = laddr.Addr() & cpu->mmu_tc.lmask;
@@ -746,7 +814,7 @@ m68030ATCTable::MMUSearch(busaddr laddr)
 
 // デバッグ表示。
 std::string
-m68030ATCTable::LineToStr(const m68030ATCLine *a) const
+m68030ATCTable_Custom::LineToStr(const m68030ATCLine *a) const
 {
 	uint32 laddr = a->GetLAddr();
 
@@ -765,6 +833,250 @@ m68030ATCTable::LineToStr(const m68030ATCLine *a) const
 	}
 }
 
+#else
+
+// コンストラクタ
+m68030ATCTable_Motorola::m68030ATCTable_Motorola(MPU68030Device *cpu_)
+{
+	cpu = cpu_;
+
+#if defined(ATC_ORDER128)
+	for (uint i = 0; i < LINES; i++) {
+		uint128 n = (uint128)i;
+		order |= n << (i * 5);
+	}
+#else
+	for (uint i = 0; i < LINES; i++) {
+		order[i] = i;
+	}
+#endif
+
+	Flush();
+}
+
+// デストラクタ
+m68030ATCTable_Motorola::~m68030ATCTable_Motorola()
+{
+}
+
+// この ATC テーブルのエントリをすべてフラッシュする。
+void
+m68030ATCTable_Motorola::Flush()
+{
+	// 全部無効にするので、無効にしたのを最後尾に回す必要ない。
+	for (auto& e : line) {
+		m68030ATCLine *a = &e;
+		a->Invalidate();
+	}
+}
+
+// ATC の fc, mask が一致するエントリをフラッシュする。
+// 命令からコールされる。
+void
+m68030ATCTable_Motorola::Flush(uint32 fc, uint32 mask)
+{
+	for (auto& e : line) {
+		m68030ATCLine *a = &e;
+		if (((a->GetFC() ^ fc) & mask) == 0) {
+			Invalidate(a);
+		}
+	}
+}
+
+// ATC の fc, mask と addr が一致するエントリをフラッシュする。
+// 命令からコールされる。
+void
+m68030ATCTable_Motorola::Flush(uint32 fc, uint32 mask, uint32 addr)
+{
+	for (auto& e : line) {
+		m68030ATCLine *a = &e;
+		if (a->GetLAddr() == addr && ((a->GetFC() ^ fc) & mask) == 0) {
+			Invalidate(a);
+		}
+	}
+}
+
+// ATC から laddr を探す。
+template <bool USE_STAT>
+m68030ATCLine *
+m68030ATCTable_Motorola::LookupTempl(const busaddr& laddr)
+{
+	uint32 tag = (laddr.Addr() & cpu->mmu_tc.lmask) | (laddr.GetFC() << 1);
+
+#if defined(ATC_ORDER128)
+	uint128 order_ = order;
+	for (uint i = 0; i < LINES; i++) {
+		uint n = (uint)order_ & 0x1f;
+		m68030ATCLine *a = &line[n];
+		if (__predict_true(a->GetTag() == tag)) {
+			if (USE_STAT) {
+				stat_atchit[i]++;
+			}
+			return a;
+		}
+		order_ >>= 5;
+	}
+#else
+	for (uint i = 0; i < LINES; i++) {
+		uint n = order[i];
+		m68030ATCLine *a = &line[n];
+		if (__predict_true(a->GetTag() == tag)) {
+			if (USE_STAT) {
+				stat_atchit[i]++;
+			}
+			return a;
+		}
+	}
+#endif
+	// ミスは別でカウントしているので不要。
+	return NULL;
+}
+
+m68030ATCLine *
+m68030ATCTable_Motorola::Lookup(const busaddr& laddr)
+{
+	return LookupTempl<true>(laddr);
+}
+
+m68030ATCLine *
+m68030ATCTable_Motorola::Lookup_nostat(const busaddr& laddr)
+{
+	return LookupTempl<false>(laddr);
+}
+
+#if defined(ATC_ORDER128)
+// line[idx] が order の何番目にあるかを返す。
+inline uint
+m68030ATCTable_Motorola::FindOrder(uint idx) const
+{
+	uint128 order_ = order;
+	uint i;
+	for (i = 0; i < LINES - 1; i++) {
+		if (((uint)order_ & 0x1f) == idx) {
+			return i;
+		}
+		order_ >>= 5;
+	}
+	// 最後の一つ手前までで一致しなければ、最後の要素で一致するはず。
+	return i;
+}
+#endif
+
+// エントリ a を無効にして最後尾に回す。
+// 引数なしの Flush() はこれを呼ばないので注意。
+void
+m68030ATCTable_Motorola::Invalidate(m68030ATCLine *a)
+{
+	a->Invalidate();
+
+	uint n = a - &line[0];
+#if defined(ATC_ORDER128)
+	uint i = FindOrder(n);
+	if (i == LINES - 1) {
+		return;
+	}
+	uint128 mask = (~(uint128)0) << (i * 5);
+	uint128 tmph = (order >> 5) & mask;
+	uint128 tmpl = (order & ~mask);
+	uint128 tmpb = (uint128)n << ((LINES - 1) * 5);
+	order = tmph | tmpl | tmpb;
+#else
+	uint pos;
+	for (pos = 0; pos < order.size() - 1; pos++) {
+		if (order[pos] == n) {
+			goto move;
+		}
+	}
+	// 最後の要素は比較しなくてもいい。
+	return;
+ move:
+	memmove(&order[pos], &order[pos + 1], LINES - pos - 1);
+	order.back() = n;
+#endif
+}
+
+// この要素を先頭に移動。
+void
+m68030ATCTable_Motorola::MoveHead(m68030ATCLine *a)
+{
+#if defined(ATC_ORDER128)
+	uint n = a - &line[0];
+	uint i = FindOrder(n);
+	if (__predict_true(i == 0)) {
+		return;
+	}
+	uint128 maskl = (~(uint128)0) << (i * 5);
+	uint128 maskh = maskl << 5;
+	uint128 tmpl = (order & ~maskl) << 5;
+	uint128 tmph = (order & maskh);
+	order = tmph | tmpl | n;
+#else
+	// 効率はあとで考える。
+	uint n = a - &line[0];
+	if (order.front() == n) {
+		return;
+	}
+	uint pos;
+	for (pos = 1; pos < order.size(); pos++) {
+		if (order[pos] == n) {
+			break;
+		}
+	}
+	memmove(&order[1], &order[0], pos);
+	order.front() = n;
+#endif
+}
+
+// このテーブルのうち最も古い要素を差し出す。
+m68030ATCLine *
+m68030ATCTable_Motorola::RemoveTail()
+{
+#if defined(ATC_ORDER128)
+	uint n = (uint)(order >> ((LINES - 1) * 5)) & 0x1f;
+	return &line[n];
+#else
+	return &line[order.back()];
+#endif
+}
+
+// テーブルサーチを行う。
+// テーブルという用語がぶつかっているので MMU Search にしてある。
+m68030ATCLine *
+m68030ATCTable_Motorola::MMUSearch(const busaddr& laddr)
+{
+	m68030ATCLine *a = RemoveTail();
+	a->tag = (laddr.Addr() & cpu->mmu_tc.lmask) | (laddr.GetFC() << 1);
+
+	m68030MMU mmu(cpu, loglevel);
+	mmu.search(7, laddr);
+	mmu.make_atc(a);
+
+	return a;
+}
+
+// デバッグ表示。
+std::string
+m68030ATCTable_Motorola::LineToStr(const m68030ATCLine *a) const
+{
+	uint32 fc    = a->GetFC();
+	uint32 laddr = a->GetLAddr();
+
+	if (!a->IsBusError()) {
+		uint32 paddr = a->GetPAddr();
+		uint32 ci    = a->IsCInhibit();
+		uint32 wp    = a->IsWProtect();
+		uint32 mod   = a->IsModified();
+		return indent_format(1,
+			"ATC: match %u:$%08x -> $%08x CI=%u WP=%u M=%u",
+			fc, laddr, paddr, ci, wp, mod);
+	} else {
+		return indent_format(1,
+			"ATC: match %u:$%08x -> BusErr",
+			fc, laddr);
+	}
+}
+
+#endif // M68030_CUSTOM_ATC
 
 //
 // テーブルサーチ
@@ -844,7 +1156,8 @@ m68030MMU::search(int level, busaddr laddr)
 
 	// ここから図9-25。
 
-	// 使用するルートポインタを決定
+	// 使用するルートポインタを決定。
+	// m_desc2 のマスクは使うところで行っている。
 	if (__predict_true(cpu->mmu_tc.sre) && is_super) {
 		rpname = "SRP";
 		m_desc1 = cpu->GetSRPh();
@@ -879,11 +1192,12 @@ m68030MMU::search(int level, busaddr laddr)
 		// たぶん検索レベルを1つ消費するはず。未確認。
 		level--;
 
+		uint32 tableaddr = m_desc2 & 0xfffffff0U;
 		MMULOG(3, 2, "%s: %s tableaddr=$%08x idx=$%x", lam_func,
-			m_lvname[x], m_desc2, m_lv[x]);
+			m_lvname[x], tableaddr, m_lv[x]);
 
 		// ディスクリプタをフェッチ
-		if (fetch_desc(m_desc2, m_lv[x]) == false) {
+		if (fetch_desc(tableaddr, m_lv[x]) == false) {
 			return;
 		}
 
@@ -1135,7 +1449,6 @@ m68030MMU::fetch_desc(uint32 tableaddr, int idx)
 void
 m68030MMU::make_atc(m68030ATCLine *a)
 {
-	std::string buf;
 	uint32 paddr;
 
 	a->data = 0;
@@ -1148,13 +1461,17 @@ m68030MMU::make_atc(m68030ATCLine *a)
 	 case NORMAL:	// ノーマル
 	 case INDIRECT:	// 間接
 		paddr = (m_descsize == 4) ? m_desc1 : m_desc2;
-		MMULOG(3, 2, "%s: type=NORMAL paddr=$%08x", lam_func,
-			paddr & 0xffffff00);
+		// IS,PS の部分は反映しない。
+		paddr &= cpu->mmu_tc.lmask;
+		MMULOG(3, 2, "%s: type=NORMAL paddr=$%08x", lam_func, paddr);
 		break;
 
 	 case EARLY:	// アーリーターミネーション
+	 {
 		paddr = (m_descsize == 4) ? m_desc1 : m_desc2;
-		buf = string_format("type=EARLY paddr=$%08x", paddr & 0xffffff00);
+		// IS,PS の部分は反映しない。
+		paddr &= cpu->mmu_tc.lmask;
+		std::string buf = string_format("type=EARLY paddr=$%08x", paddr);
 
 		// 残ってるビットも足して返す
 		for (int i = x + 1; i <= TID; i++) {
@@ -1165,12 +1482,13 @@ m68030MMU::make_atc(m68030ATCLine *a)
 		}
 		MMULOG(3, 2, "%s: %s", lam_func, buf.c_str());
 		break;
+	 }
+
 	 default:
 		PANIC("corrupted m_type=%u", (uint)m_type);
 	}
 
-	// PS の部分は反映しない
-	a->paddr = paddr & cpu->mmu_tc.lmask;
+	a->paddr = paddr;
 
 	if (m_ci)
 		a->data |= m68030ATCLine::CINHIBIT;
@@ -1198,7 +1516,7 @@ m68030MMU::make_atc_debugger() const
 	 {
 		uint32 descaddr;
 		descaddr = (m_descsize == 4) ? m_desc1 : m_desc2;
-		descaddr &= 0xffffff00;
+		descaddr &= cpu->mmu_tc.lmask;
 		paddr = busaddr(descaddr);
 		break;
 	 }
@@ -1207,7 +1525,7 @@ m68030MMU::make_atc_debugger() const
 	 {
 		uint32 descaddr;
 		descaddr = (m_descsize == 4) ? m_desc1 : m_desc2;
-		descaddr &= 0xffffff00;
+		descaddr &= cpu->mmu_tc.lmask;
 		// 残ってるビットも足して返す
 		for (int i = x + 1; i <= TID; i++) {
 			if (cpu->mmu_tc.tix[i] > 0) {
@@ -1319,22 +1637,23 @@ MPU68030Device::TranslateRead()
 	m68030ATCLine *a;
 	busaddr& laddr = bus.laddr;
 	uint32 addr = laddr.Addr();
-	uint32 fc   = laddr.GetFC();
 
 	// 状態表示
-	putlog(3, "%s:  enter  %c:$%08x pc=%c:$%08x", __func__,
+	putlog(3, "%s:  enter  %c.$%08x pc=%c.$%08x", __func__,
 		(laddr.IsSuper() ? 'S' : 'U'),
 		addr,
 		IsSuper() ? 'S' : 'U',
 		ppc);
 
-	m68030ATCTable *table = atc.fctables[fc];
+#if defined(M68030_CUSTOM_ATC)
+	uint32 fc = laddr.GetFC();
+	m68030ATCTable_Custom *table = atc.fctables[fc];
 	uint8 n = table->hash[addr >> 12];
 	if (__predict_true((int8)n >= 0)) {
 		// ATC #(n)
 		table->atcstat.total++;
 		a = &table->line[n];
-	} else if (n == m68030ATCTable::HASH_NONE) {
+	} else if (n == m68030ATCTable_Custom::HASH_NONE) {
 		if (__predict_true(mmu_tc.e)) {
 			// TC.E 有効で対応なしなら、テーブルサーチ。
 			table->atcstat.total++;
@@ -1344,7 +1663,7 @@ MPU68030Device::TranslateRead()
 			// TC.E 無効。(total もカウントしない)
 			return true;
 		}
-	} else if (n == m68030ATCTable::HASH_TT) {
+	} else if (n == m68030ATCTable_Custom::HASH_TT) {
 		// TT。CheckTT で外れたかどうかはカウントしない。ほぼ 0 なので。
 		table->atcstat.total++;
 		table->atcstat.tthit++;
@@ -1358,6 +1677,26 @@ MPU68030Device::TranslateRead()
 			a = table->MMUSearch(laddr);
 		}
 	}
+#else
+	m68030ATCTable_Motorola *table = atc.table.get();
+	// TT は TC.E とは独立しているので先に調べる。
+	if (CheckTT()) {
+		table->atcstat.total++;
+		table->atcstat.tthit++;
+		return true;
+	}
+	// TT.E 無効なら何もせず終了。
+	if (__predict_false(mmu_tc.e == false)) {
+		return true;
+	}
+	// ATC を検索。なければテーブルサーチ。
+	table->atcstat.total++;
+	a = atc.table->Lookup(laddr);
+	if (__predict_false(a == NULL)) {
+		table->atcstat.miss++;
+		a = atc.table->MMUSearch(laddr);
+	}
+#endif
 
 	// ATC a でマッチした
 	table->MoveHead(a);
@@ -1378,22 +1717,23 @@ MPU68030Device::TranslateWrite()
 	m68030ATCLine *a;
 	busaddr& laddr = bus.laddr;
 	uint32 addr = laddr.Addr();
-	uint32 fc   = laddr.GetFC();
 
 	// 状態表示
-	putlog(3, "%s: enter  %c:$%08x pc=%c:$%08x", __func__,
+	putlog(3, "%s: enter  %c.$%08x pc=%c.$%08x", __func__,
 		(laddr.IsSuper() ? 'S' : 'U'),
 		addr,
 		IsSuper() ? 'S' : 'U',
 		ppc);
 
-	m68030ATCTable *table = atc.fctables[fc];
+#if defined(M68030_CUSTOM_ATC)
+	uint32 fc = laddr.GetFC();
+	m68030ATCTable_Custom *table = atc.fctables[fc];
 	uint8 n = table->hash[addr >> 12];
 	if (__predict_true((int8)n >= 0)) {
 		// ATC #(n)
 		table->atcstat.total++;
 		a = &table->line[n];
-	} else if (n == m68030ATCTable::HASH_NONE) {
+	} else if (n == m68030ATCTable_Custom::HASH_NONE) {
 		if (__predict_true(mmu_tc.e)) {
 			// TC.E 有効で対応なしなら、テーブルサーチ。
 			table->atcstat.total++;
@@ -1402,7 +1742,7 @@ MPU68030Device::TranslateWrite()
 			// TC.E 無効。(total もカウントしない)
 			return true;
 		}
-	} else if (n == m68030ATCTable::HASH_TT) {
+	} else if (n == m68030ATCTable_Custom::HASH_TT) {
 		// TT。CheckTT で外れたかどうかはカウントしない。ほぼ 0 なので。
 		table->atcstat.total++;
 		table->atcstat.tthit++;
@@ -1425,6 +1765,36 @@ MPU68030Device::TranslateWrite()
 		table->atcstat.miss++;
 		a = table->MMUSearch(laddr);
 	}
+#else
+	m68030ATCTable_Motorola *table = atc.table.get();
+	// TT は TC.E とは独立しているので先に調べる。
+	if (CheckTT()) {
+		table->atcstat.total++;
+		table->atcstat.tthit++;
+		return true;
+	}
+	// TT.E 無効なら何もせず終了。
+	if (__predict_false(mmu_tc.e == false)) {
+		return true;
+	}
+	// ATC を検索。
+	table->atcstat.total++;
+	a = atc.table->Lookup(laddr);
+	if (a) {
+		// ライトアクセスなので、WP でなく Modified == 0 なら
+		// Modified を立てるため、このエントリを破棄して改めて
+		// テーブルサーチを行う。
+		if (a->IsWProtect() == false && a->IsModified() == false) {
+			table->Invalidate(a);
+			table->atcstat.miss++;
+			a = atc.table->MMUSearch(laddr);
+		}
+	} else {
+		// なければテーブルサーチ。
+		table->atcstat.miss++;
+		a = atc.table->MMUSearch(laddr);
+	}
+#endif
 
 	// ATC a でマッチした
 	table->MoveHead(a);
@@ -1453,22 +1823,23 @@ MPU68030Device::TranslatePeek(busaddr laddr)
 	const m68030ATCLine *a;
 	busaddr paddr;
 	uint32 addr = laddr.Addr();
-	uint32 fc   = laddr.GetFC();
 
 	// 状態表示
-	putlog(5, "%s:  enter  %c:$%08x", __func__,
+	putlog(5, "%s:  enter  %c.$%08x", __func__,
 		(laddr.IsSuper() ? 'S' : 'U'),
 		addr);
 
-	m68030ATCTable *table = atc.fctables[fc];
+#if defined(M68030_CUSTOM_ATC)
+	uint32 fc = laddr.GetFC();
+	m68030ATCTable_Custom *table = atc.fctables[fc];
 	uint8 n = table->hash[addr >> 12];
 	// PS<4KB のケースを先に解決する。
-	if (__predict_false(n == m68030ATCTable::HASH_SUB)) {
+	if (__predict_false(n == m68030ATCTable_Custom::HASH_SUB)) {
 		a = table->FindSub(laddr);
 		if (a) {
 			n = a - &table->line[0];
 		} else {
-			n = m68030ATCTable::HASH_NONE;
+			n = m68030ATCTable_Custom::HASH_NONE;
 		}
 	}
 	if (__predict_true((int8)n >= 0)) {
@@ -1478,7 +1849,7 @@ MPU68030Device::TranslatePeek(busaddr laddr)
 		paddr |= addr & mmu_tc.pgmask;
 		putlog(5, "%s:  result $%08x (match atc)", __func__, paddr.Addr());
 		return paddr;
-	} else if (n == m68030ATCTable::HASH_NONE) {
+	} else if (n == m68030ATCTable_Custom::HASH_NONE) {
 		if (__predict_true(mmu_tc.e)) {
 			// TC.E 有効で対応なしなら、こっそりテーブルサーチ。
 
@@ -1522,6 +1893,55 @@ MPU68030Device::TranslatePeek(busaddr laddr)
 		}
 		return BusAddr::BusErr;
 	}
+#else
+	// まず TT をこっそりチェック。
+	for (uint i = 0; i < 2; i++) {
+		const m68030TT& tt = mmu_tt[i];
+		if (tt.Match(laddr)) {
+			// 一致した。
+			// CI はここでは使わないため、一致したことだけわかればよい
+			putlog(5, "%s:  result $%08x (match tt)", __func__, paddr.Addr());
+			return paddr;
+		}
+	}
+
+	// TC.E が無効ならここまで。
+	if (__predict_false(mmu_tc.e == false)) {
+		paddr = laddr;
+		putlog(5, "%s:  result $%08x (no translation)", __func__, paddr.Addr());
+		return paddr;
+	}
+
+	// こっそり ATC を検索。
+	m68030ATCTable_Motorola *table = atc.table.get();
+	a = table->Lookup_nostat(laddr);
+	if (__predict_true(a)) {
+		paddr = busaddr(a->GetPAddr());
+		paddr |= addr & mmu_tc.pgmask;
+		putlog(5, "%s:  result $%08x (match atc)", __func__, paddr.Addr());
+		return paddr;
+	}
+
+	// こっそりテーブルサーチ。
+	// mmu.search() はさすがに bus を使うので事前に退避。
+	m68kbus backup = bus;
+
+	m68030MMU mmu(this, loglevel);
+	mmu.m_debugger = true;
+	mmu.search(7, laddr);
+	paddr = mmu.make_atc_debugger();
+	// リストア
+	bus = backup;
+
+	if (paddr.IsBusErr()) {
+		// TC が有効だがヒットしなかったらバスエラー
+		putlog(5, "%s:  result BusErr", __func__);
+	} else {
+		paddr |= addr & mmu_tc.pgmask;
+		putlog(5, "%s:  result $%08x (table search)", __func__, paddr.Addr());
+	}
+	return paddr;
+#endif
 }
 
 //
@@ -1552,15 +1972,22 @@ MPU68030Device::get_fc()
 
 // MMU 不当命令 (2ワード目で確定)
 void
-MPU68030Device::mmu_op_illg2()
+MPU68030Device::ops_mmu30_illg2()
 {
 	putlog(1, "MMU illegal instruction %04x %04x", ir, ir2);
 	Exception(M68K::EXCEP_FLINE);
 }
 
+// PFLUSHA 命令
+void
+MPU68030Device::ops_mmu30_pflusha()
+{
+	atc.flush();
+}
+
 // PFLUSH fc,#mask 命令 (EA を持たない方)
 void
-MPU68030Device::mmu_op_pflush()
+MPU68030Device::ops_mmu30_pflush()
 {
 	uint32 mask;
 	uint32 fc;
@@ -1572,7 +1999,7 @@ MPU68030Device::mmu_op_pflush()
 
 // PFLUSH fc,#mask,ea 命令
 void
-MPU68030Device::mmu_op_pflush_ea()
+MPU68030Device::ops_mmu30_pflush_ea()
 {
 	uint32 ea;
 	uint32 mask;
@@ -1587,14 +2014,15 @@ MPU68030Device::mmu_op_pflush_ea()
 
 // PLOADR/PLOADW 命令
 void
-MPU68030Device::mmu_op_pload()
+MPU68030Device::ops_mmu30_pload()
 {
 	uint32 ea;
 	uint32 fc;
 	busaddr laddr;
+	m68030ATCLine *a;
 
 	if ((ir2 & 0x01e0) != 0) {
-		mmu_op_illg2();
+		ops_mmu30_illg2();
 		return;
 	}
 	ea = cea_copro();
@@ -1608,16 +2036,16 @@ MPU68030Device::mmu_op_pload()
 		laddr = busaddr(ea) | busaddr::FC(fc) | BusAddr::W;
 	}
 
-	m68030ATCTable *table = atc.fctables[fc];
-	m68030ATCLine *a;
+#if defined(M68030_CUSTOM_ATC)
+	m68030ATCTable_Custom *table = atc.fctables[fc];
 	uint8 n = table->hash[laddr.Addr() >> 12];
 	// PS<4KB のケースを先に解決する。
-	if (__predict_false(n == m68030ATCTable::HASH_SUB)) {
+	if (__predict_false(n == m68030ATCTable_Custom::HASH_SUB)) {
 		a = table->FindSub(laddr);
 		if (a) {
 			n = a - &table->line[0];
 		} else {
-			n = m68030ATCTable::HASH_NONE;
+			n = m68030ATCTable_Custom::HASH_NONE;
 		}
 	}
 	if ((int8)n >= 0) {
@@ -1631,7 +2059,7 @@ MPU68030Device::mmu_op_pload()
 				table->MMUSearch(laddr);
 			}
 		}
-	} else if (n == m68030ATCTable::HASH_NONE) {
+	} else if (n == m68030ATCTable_Custom::HASH_NONE) {
 		if (__predict_true(mmu_tc.e)) {
 			// TC.E 有効で対応なしなら、テーブルサーチを行って
 			// ATC を作成。
@@ -1639,14 +2067,39 @@ MPU68030Device::mmu_op_pload()
 		} else {
 			// TC.E 無効なら何もしない?
 		}
-	} else if (n == m68030ATCTable::HASH_TT) {
+	} else if (n == m68030ATCTable_Custom::HASH_TT) {
 		// TT の領域なら何もしてはいけない。
 	}
+#else
+	// TT の領域なら何もしてはいけない。
+	if (CheckTT()) {
+		return;
+	}
+	// TE.E 無効なら何もしない?
+	if (__predict_false(mmu_tc.e == false)) {
+		return;
+	}
+	m68030ATCTable_Motorola *table = atc.table.get();
+	a = table->Lookup(laddr);
+	if (a) {
+		if (laddr.IsWrite()) {
+			// 命令が ploadw でエントリが WProtect==0 && Modified==0 なら、
+			// 一回破棄して書き込み用に作り直す。
+			if (a->IsWProtect() == false && a->IsModified() == false) {
+				table->Invalidate(a);
+				table->MMUSearch(laddr);
+			}
+		}
+	} else {
+		// テーブルサーチを行って ATC を作成。
+		table->MMUSearch(laddr);
+	}
+#endif
 }
 
 // PTESTR/PTESTW 命令
 void
-MPU68030Device::mmu_op_ptest()
+MPU68030Device::ops_mmu30_ptest()
 {
 	uint level = (ir2 >> 10) & 7;
 	busaddr rw = (ir2 & 0x0200) ? BusAddr::R : BusAddr::W;
@@ -1662,35 +2115,36 @@ MPU68030Device::mmu_op_ptest()
 	if (level == 0) {
 		if (rn != 0) {
 			// レベル0で An 指定なら Fライン例外
-			mmu_op_illg2();
+			ops_mmu30_illg2();
 			return;
 		}
 		CYCLE(22);
 
-		// laddr は IS と PS のところを落としたもの。
-		// ssw_laddr のアドレスは IS を落とさないもの (PSは不問)。
+		// addr は IS と PS のところを落としたもの。
+		// laddr は IS を残したもの (PSは不問)。
 		busaddr laddr = busaddr(ea) | busaddr::FC(fc) | rw;
-		uint32 addr = ea & mmu_tc.lmask;
 
-		m68030ATCTable *table = atc.fctables[fc];
 		m68030ATCLine *a = NULL;
+#if defined(M68030_CUSTOM_ATC)
+		m68030ATCTable_Custom *table = atc.fctables[fc];
+		uint32 addr = ea & mmu_tc.lmask;
 		uint8 n = table->hash[addr >> 12];
 		// PS<4KB のケースを先に解決する。
-		if (__predict_false(n == m68030ATCTable::HASH_SUB)) {
+		if (__predict_false(n == m68030ATCTable_Custom::HASH_SUB)) {
 			a = table->FindSub(laddr);
 			if (a) {
 				n = a - &table->line[0];
 			} else {
-				n = m68030ATCTable::HASH_NONE;
+				n = m68030ATCTable_Custom::HASH_NONE;
 			}
 		}
 		if (__predict_true((int8)n >= 0)) {
 			// ATC #(n) で見付かった。
 			a = &table->line[n];
-		} else if (n == m68030ATCTable::HASH_NONE) {
+		} else if (n == m68030ATCTable_Custom::HASH_NONE) {
 			// ATC に見付からなかった。Invalid を立てる。
 			mmusr = m68030MMUSR::I;
-		} else if (n == m68030ATCTable::HASH_TT) {
+		} else if (n == m68030ATCTable_Custom::HASH_TT) {
 			for (int i = 0; i < 2; i++) {
 				m68030TT& tt = mmu_tt[i];
 				if (tt.Match(laddr)) {
@@ -1698,7 +2152,23 @@ MPU68030Device::mmu_op_ptest()
 				}
 			}
 		}
-
+#else
+		m68030ATCTable_Motorola *table = atc.table.get();
+		for (uint i = 0; i < 2; i++) {
+			const m68030TT& tt = mmu_tt[i];
+			if (tt.Match(laddr)) {
+				mmusr |= m68030MMUSR::T;
+				goto done;
+			}
+		}
+		//XXX laddr &= lmask ?
+		a = table->Lookup(laddr);
+		if (a == NULL) {
+			// ATC に見付からなかったら Invalid を立てる。
+			mmusr = m68030MMUSR::I;
+			goto done;
+		}
+#endif
 		if (a) {
 			// 見付かれば Modified 等の状態を返す。
 			if (a->IsBusError()) {
@@ -1762,5 +2232,8 @@ MPU68030Device::mmu_op_ptest()
 		}
 	}
 
+#if !defined(M68030_CUSTOM_ATC)
+ done:
+#endif
 	SetMMUSR(mmusr);
 }
