@@ -71,7 +71,7 @@ MPU680x0Device::ExecShort(Event *ev)
 	// 外部割り込みの起動は VM 側で処理している。
 
 	int cycle = used_cycle - cycle_start;
-	ev->time = cycle * clock_nsec + buswait;
+	ev->time = cycle * clock_tsec + buswait;
 	scheduler->StartEvent(ev);
 }
 
@@ -491,8 +491,7 @@ MPU680x0Device::ExceptionReset()
 	constexpr uint32 info = BranchHistory_m680x0::InfoException(vector);
 	exhist.AddEntry(reg.pc | 1, 0, info);
 	brhist.AddEntry(reg.pc | 1, 0, info);
-	// デバッガに通知 (例外ブレーク用)。こっちのベクタは 0 のままでよい。
-	debugger->NotifyExceptionMain(vector);
+	last_vector = vector;
 
 	// RESET 信号線をネゲートしてから SP の読み込み開始まで 4クロック
 	// (Section 7.8, Figure 7-64)
@@ -561,7 +560,8 @@ MPU680x0Device::ExceptionReset()
 // ただし以下の例外はここではなくそれぞれ固有のを呼ぶこと。
 // o リセット例外は ExceptionReset()
 // o 割り込み例外は ExceptionInterrupt()
-// o TRAP#15 例外は ExceptionTrap15()
+// o TRAP#0  例外は ExceptionTrap0()  .. NetBSD システムコール用
+// o TRAP#15 例外は ExceptionTrap15() .. IOCS コール用
 // o バスエラー・アドレスエラーは ExceptionBuserr()
 void
 MPU680x0Device::Exception(uint vector)
@@ -570,6 +570,44 @@ MPU680x0Device::Exception(uint vector)
 	ExceptionGeneric(vector, info);
 }
 
+// TRAP #0 の例外処理を行う。
+// 処理自体は汎用の Exception() とまったく同じだが、
+// NetBSD システムコールの時に分岐履歴の内容を変えるため入口を分けてある。
+void
+MPU680x0Device::ExceptionTrap0()
+{
+	// 今発生した TRAP #0 が NetBSD/m68k システムコールっぽいか調べる。
+	//
+	// NetBSD/m68k 方面をやってる時は TRAP #0 はシステムコールを表示して
+	// ほしい。一方 Human68k などでは TRAP #0 は別用途なので、システムコール
+	// かのように表示されるのは紛らわしいので、
+	// 出来れば今呼ばれたこれが NetBSD/m68k システムコールなのか、そうでない
+	// TRAP #0 なのかは区別したい。
+	//
+	// NetBSD/m68k カーネルが実行中かどうかは厳密には分からないが、これが
+	// 呼ばれた時点で、
+	// 1) MMU がオン。
+	// 2) カーネルのエントリポイントの最初の命令が move.w #$2700,sr 命令。
+	// を満たせば NetBSD/m68k システムコールと判定することにする。
+	// カーネルエントリポイントは機種ごとに固有で、不変ではないものの
+	// ブートローダ側にも影響があるためおそらくそう簡単には変わらないだろう。
+	// だめならまた考える。
+
+	const uint vector = M68K::EXCEP_TRAP0;
+	uint32 info;
+	if (__predict_true(mmu_enable)) {
+		// カーネルエントリポイントの最初の命令はどれも move.w #$2700,sr。
+		if (mainbus->Peek4(netbsd_entrypoint) == 0x46fc2700) {
+			// NetBSD/m68k カーネルっぽい。
+			info = BranchHistory_m680x0::InfoNetBSDSyscall(reg.D[0] & 0xffff);
+			ExceptionGeneric(vector, info);
+			return;
+		}
+	}
+	// その他の TRAP#0 っぽい
+	Exception(vector);
+}
+
 // TRAP #15 の例外処理を行う。
 // 処理自体は汎用の Exception() とまったく同じだが、
 // IOCS コールの時に分岐履歴の内容を変えるため入口を分けてある。
@@ -597,11 +635,12 @@ MPU680x0Device::ExceptionTrap15()
 	if (mainbus->Peek1(0xcb6) == 0x02 && mainbus->Peek1(0xcb7) == 0x03) {
 		// IOCS コールっぽい
 		info = BranchHistory_m680x0::InfoIOCSCall(reg.D[0] & 0xff);
-	} else {
-		// TRAP#15 っぽい
-		info = BranchHistory_m680x0::InfoException(vector);
+		ExceptionGeneric(vector, info);
+		return;
 	}
-	ExceptionGeneric(vector, info);
+
+	// その他の TRAP#15 っぽい
+	Exception(vector);
 }
 
 // F ライン例外処理を行う。
@@ -640,12 +679,11 @@ MPU680x0Device::ExceptionGeneric(uint ext_vector, uint32 info)
 	uint vector = ext_vector & 0xff;
 
 	// 例外履歴に記録 (例外発生はブランチ履歴にも記録)
+	last_vector = vector;
 	excep_counter[vector]++;
 	uint32 from = ppc | (IsSuper() ? 1 : 0);
 	exhist.AddEntry(from, 0, info);
 	brhist.AddEntry(from, 0, info);
-	// デバッガに通知 (例外ブレーク用)
-	debugger->NotifyExceptionMain(vector);
 
 	// 状態を保存
 	uint16 sr = GetSR();
@@ -707,13 +745,12 @@ MPU680x0Device::ExceptionBuserr(uint vector)
 		"vector=%u", vector);
 
 	// 例外履歴に記録 (例外発生はブランチ履歴にも記録)
+	last_vector = vector;
 	excep_counter[vector]++;
 	uint32 from = ppc | (IsSuper() ? 1 : 0);
 	uint32 info = BranchHistory_m680x0::InfoException(vector);
 	exhist.AddEntry(from, 0, info);
 	brhist.AddEntry(from, 0, info);
-	// デバッガに通知 (例外ブレーク用)
-	debugger->NotifyExceptionMain(vector);
 
 	// 現状 68030 のバスエラーに short/long の区別はないので全部 long 相当。
 	CYCLE3(busfault);
@@ -802,13 +839,12 @@ MPU680x0Device::ExceptionInterrupt()
 	}
 
 	// 例外履歴に記録 (例外発生はブランチ履歴にも記録)
+	last_vector = vector;
 	excep_counter[vector]++;
 	uint32 from = ppc | (IsSuper() ? 1 : 0);
 	uint32 info = BranchHistory_m680x0::InfoException(vector);
 	exhist.AddEntry(from, 0, info);
 	brhist.AddEntry(from, 0, info);
-	// デバッガに通知 (例外ブレーク用)
-	debugger->NotifyExceptionMain(vector);
 
 	// 状態を保存
 	uint16 oldsr = GetSR();
@@ -834,7 +870,7 @@ MPU680x0Device::ExceptionInterrupt()
 		ExceptionBuserr(vector2);
 	}
 
-	return (used_cycle - cycle_start) * clock_nsec + bd.GetWait();
+	return (used_cycle - cycle_start) * clock_tsec + bd.GetWait();
 }
 
 // LC040 の未実装浮動小数点命令例外。
@@ -844,13 +880,12 @@ MPU680x0Device::ExceptionFPLC(uint32 ea)
 	const uint vector = M68K::EXCEP_FLINE;
 
 	// 例外履歴に記録 (例外発生はブランチ履歴にも記録)
+	last_vector = vector;
 	excep_counter[vector]++;
 	uint32 from = ppc | (IsSuper() ? 1 : 0);
 	constexpr uint32 info = BranchHistory_m680x0::InfoException(vector);
 	exhist.AddEntry(from, 0, info);
 	brhist.AddEntry(from, 0, info);
-	// デバッガに通知 (例外ブレーク用)
-	debugger->NotifyExceptionMain(vector);
 
 	// 状態を保存
 	uint16 sr = GetSR();
