@@ -25,7 +25,7 @@
 #define m88100opf_FP_TD(x)	(((x) >> 5) & 3)
 
 // cmp のやつ
-static inline uint32
+inline uint32
 acc_cmp(uint32 a, uint32 b)
 {
 	uint32 rv = 0;
