@@ -224,7 +224,7 @@ m88200::MonitorScreenATC(Monitor *, TextScreen& screen)
 
 		const m88200BATC& b = batc[i];
 		if (b.IsValid()) {
-			screen.Print(x + 4, y, "%c:%04x'0000 %04x'0000 %c%c%c%c",
+			screen.Print(x + 4, y, "%c.%04x'0000 %04x'0000 %c%c%c%c",
 				b.IsS() ? 'S' : 'U',
 				b.lba >> 16, b.pba >> 16,
 				(b.stat & DESC_WT) ? 'T' : '-',
@@ -257,7 +257,7 @@ m88200::MonitorScreenATC(Monitor *, TextScreen& screen)
 
 		const m88200PATC& p = patc[i];
 		if (p.IsValid()) {
-			screen.Print(x + 4,  y, "%c:%05x'000 %05x'000 %c%c%c%c%c",
+			screen.Print(x + 4,  y, "%c.%05x'000 %05x'000 %c%c%c%c%c",
 				p.IsS() ? 'S' : 'U',
 				p.lpa >> 12, p.pfa >> 12,
 				(p.stat & DESC_WT) ? 'T' : '-',
@@ -1175,7 +1175,7 @@ m88200::load(uint32 addr)
 	acc_laddr = addr;
 	acc_read  = true;
 	if (__predict_false(Translate() == false)) {
-		putlog(2, "Translation BusError %c:$%08x",
+		putlog(2, "Translation BusError %c.$%08x",
 			(IsSuper() ? 'S' : 'U'), acc_laddr);
 		return BusData::BusErr;
 	}
@@ -1303,7 +1303,7 @@ m88200::Translate()
 
 	// Logical address(LA) presented on PBus
 
-	putlog(3, "Translate %c:$%08x", (IsSuper() ? 'S' : 'U'), acc_laddr);
+	putlog(3, "Translate %c.$%08x", (IsSuper() ? 'S' : 'U'), acc_laddr);
 
 	// Select Area Descriptor
 	if (SelectAreaDesc() == false) {
@@ -1762,7 +1762,7 @@ m88200::CreatePATCEntry()
 		p.lpa |= PATC_S;
 	}
 	p.stat = acc_stat;
-	putlog(4, "  %s %c:$%08x:$%08x stat=%s", __func__,
+	putlog(4, "  %s %c.$%08x:$%08x stat=%s", __func__,
 		p.IsS() ? 'S' : 'U', (p.lpa & 0xfffff000U), p.pfa,
 		stat2str(p.stat).c_str());
 
