@@ -83,8 +83,8 @@ class ADPCMDevice : public IODevice
 	bool panout_L {};
 	bool panout_R {};
 
-	// 選択周波数での 1フレームにかかる時間 [nsec]
-	uint64 guest_frame_nsec {};
+	// 選択周波数での 1フレームにかかる時間 [tsec]
+	uint64 guest_frame_tsec {};
 
 	// 周波数
 	uint32 freq {};
@@ -99,8 +99,8 @@ class ADPCMDevice : public IODevice
 	// 最後に書き込んだサンプル値 (線形補間用)
 	int16 pcm0 {};
 
-	// ミキサー周波数での1フレームにかかる時間 [nsec]
-	uint64 mixer_frame_nsec {};
+	// ミキサー周波数での1フレームにかかる時間 [tsec]
+	uint64 mixer_frame_tsec {};
 
 	// ミキサー周波数にアップスキャンするための倍率。
 	// 15625 Hz なら 4(倍)。
@@ -117,6 +117,6 @@ class ADPCMDevice : public IODevice
 	static const int32 adpcm_stepsize[49];
 };
 
-static inline ADPCMDevice *GetADPCMDevice() {
+inline ADPCMDevice *GetADPCMDevice() {
 	return Object::GetObject<ADPCMDevice>(OBJ_ADPCM);
 }
