@@ -361,7 +361,7 @@ BT454Device::BT454Device()
 	// 使わないけど一応
 	readmask = 0x0f;
 
-	monitor->func = ToMonitorCallback(&BT454Device::MonitorUpdate);
+	monitor->SetCallback(&BT454Device::MonitorScreen);
 	monitor->SetSize(63, 3);
 }
 
@@ -371,7 +371,7 @@ BT454Device::~BT454Device()
 }
 
 void
-BT454Device::MonitorUpdate(Monitor *, TextScreen& screen)
+BT454Device::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	screen.Clear();
 	screen.Puts(0, 0, "Model: Bt454");
@@ -438,7 +438,7 @@ BT458Device::BT458Device()
 	// 初期化されないそうなのでゴミを入れておく
 	readmask = 0xcc;
 
-	monitor->func = ToMonitorCallback(&BT458Device::MonitorUpdate);
+	monitor->SetCallback(&BT458Device::MonitorScreen);
 	monitor->SetSize(116, 18);
 }
 
@@ -473,7 +473,7 @@ BT458Device::Init()
 }
 
 void
-BT458Device::MonitorUpdate(Monitor *, TextScreen& screen)
+BT458Device::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	screen.Clear();
 	screen.Puts(0, 0, "Model: Bt458");
