@@ -13,7 +13,7 @@
 #include "device.h"
 
 class LunafbDevice;
-class Renderer;
+class VideoRenderer;
 
 class CRTC2Device : public IODevice
 {
@@ -46,7 +46,7 @@ class CRTC2Device : public IODevice
 	uint vdisp_state {};
 
 	LunafbDevice *lunafb {};
-	Renderer *renderer {};
+	VideoRenderer *renderer {};
 
 	Event *vdisp_event {};
 };
