@@ -64,6 +64,6 @@ class NewsDipswDevice : public DipswDevice
 	bool Init() override;
 };
 
-static inline DipswDevice *GetDipswDevice() {
+inline DipswDevice *GetDipswDevice() {
 	return Object::GetObject<DipswDevice>(OBJ_DIPSW);
 }
