@@ -363,6 +363,6 @@ class DMACDevice : public IODevice
 	static const char * const seqname[SEQ_MAX];
 };
 
-static inline DMACDevice *GetDMACDevice() {
+inline DMACDevice *GetDMACDevice() {
 	return Object::GetObject<DMACDevice>(OBJ_DMAC);
 }
