@@ -322,7 +322,7 @@ FDDDevice::EventCallback(Event *ev)
 			} else {
 				event->time /= 2;
 			}
-			putlog(4, "SPIN_UP next=%uusec", (uint)(event->time / 1_usec));
+			putlog(4, "SPIN_UP next=%uusec", (uint)tsec_to_usec(event->time));
 		}
 		scheduler->StartEvent(ev);
 		break;
@@ -335,7 +335,7 @@ FDDDevice::EventCallback(Event *ev)
 		} else {
 			event->time *= 2;
 			scheduler->StartEvent(ev);
-			putlog(4, "SPIN_DOWN next=%uusec", (uint)(event->time / 1_usec));
+			putlog(4, "SPIN_DOWN next=%uusec", (uint)tsec_to_usec(event->time));
 		}
 		break;
 
@@ -389,7 +389,7 @@ FDDDevice::DoMotorOn()
 		// 使っているので、約 524msec かかる。細かいことは気にしない。
 		motor_state = SPIN_UP;
 		event->time = 262144_usec;
-		putlog(4, "SPIN_UP next=%uusec", (uint)(event->time / 1_usec));
+		putlog(4, "SPIN_UP next=%uusec", (uint)tsec_to_usec(event->time));
 	} else if (motor_state == SPIN_DOWN) {
 		// 細かいことは無視して、増速に転じる
 		motor_state = SPIN_UP;
