@@ -80,7 +80,7 @@ class FDDDevice : public Device
 	void ResetHard(bool poweron) override;
 
 	// モニタ更新 (FDC の下請け)
-	void MonitorUpdateFDD(TextScreen&, uint hd);
+	void MonitorScreenFDD(TextScreen&, uint hd);
 
 	// ユニット番号を返す
 	int GetUnitNo() const { return unit; }
