@@ -40,6 +40,6 @@ class FuseROMDevice : public IODevice
 	std::array<uint8, SRCBYTES> src {};
 };
 
-static inline FuseROMDevice *GetFuseROMDevice() {
+inline FuseROMDevice *GetFuseROMDevice() {
 	return Object::GetObject<FuseROMDevice>(OBJ_FUSEROM);
 }
