@@ -341,6 +341,6 @@ class Virt68kInterrupt : public M680x0Interrupt
 
 // LUNA-88K は sysctlr.cpp 参照。
 
-static inline InterruptDevice *GetInterruptDevice() {
+inline InterruptDevice *GetInterruptDevice() {
 	return Object::GetObject<InterruptDevice>(OBJ_INTERRUPT);
 }
