@@ -503,11 +503,6 @@ LanceDevice::WriteData(uint32 data)
 		if (reg.IsSTOP()) {
 			reg.iadr = (reg.iadr & 0xff0000) | (data & AM7990::IADR_L_MASK);
 			putlog(2, "IDAR(L)=$%06x", reg.iadr);
-
-#if 0
-			// IADR 設定時にパフォーマンス測定用実時間表示
-			scheduler->PutlogRealtime();
-#endif
 		}
 		break;
 
@@ -845,7 +840,7 @@ LanceDevice::TXCopy()
 
 	// メモリからの転送にかかった時間をざっくり計算 XXX まだ適当
 	// そのウェイト後に指定のフェーズへ。
-	uint64 t = 700 * bcnt / 16;
+	uint64 t = nsec_to_tsec(700 * bcnt / 16);
 
 	// ここが ENP なら、送信のため TXSEND フェーズへ
 	if ((tmd1 & AM7990::TMD1_ENP)) {
@@ -1121,7 +1116,7 @@ LanceDevice::RXCopy()
 
 	// メモリへの転送にかかった時間をざっくり計算 XXX まだ適当
 	// そのウェイト後に RXNEXT フェーズへ。
-	uint64 t = 700 * (dst - bufdst) / 16;
+	uint64 t = nsec_to_tsec(700 * (dst - bufdst) / 16);
 	ChangePhase(RXPhase::NEXT, t);
 }
 
