@@ -88,7 +88,7 @@ LunafbDevice::Init()
 	palette = &(bt45x->GetHostPalette())[0];
 
 	// XXX とりあえず RAM と同じウェイトを入れておく (未調査)
-	wait = busdata::Wait(1 * mpu->GetClock_nsec());
+	wait = busdata::Wait(1 * mpu->GetClock_tsec());
 
 	return true;
 }
