@@ -447,7 +447,7 @@ LunaKeyboard::Command(uint32 data)
 			data, buzzer_msec, buzzer_freq);
 
 		uint64 now = scheduler->GetVirtTime();
-		buzzer_end = now + buzzer_msec * 1_msec;
+		buzzer_end = now + msec_to_nsec(buzzer_msec);
 		// VM スレッド内なので MakeKey() ではなく KeyInput() を直接呼ぶ
 		KeyInput(KC_buzzer | KC_FLAG_MAKE);
 		Start(2_msec);
