@@ -56,6 +56,6 @@ class MainRAMDevice : public IODevice
 	bool clear_on_boot {};
 };
 
-static inline MainRAMDevice *GetMainRAMDevice() {
+inline MainRAMDevice *GetMainRAMDevice() {
 	return Object::GetObject<MainRAMDevice>(OBJ_MAINRAM);
 }
