@@ -311,12 +311,12 @@ class MFPDevice : public IODevice
 	static const busdata wait;
 	static const char *intrname[];
 	static const char *gpipname[];
-	static const uint64 prescale_ns[8];
+	static const uint64 prescale_tsec[8];
 	static const char *prescale_str[8];
 	static const uint timer_vector[4];
 	static const char *regname[MFP::RegMax];
 };
 
-static inline MFPDevice *GetMFPDevice() {
+inline MFPDevice *GetMFPDevice() {
 	return Object::GetObject<MFPDevice>(OBJ_MFP);
 }
