@@ -753,21 +753,21 @@ MPSCCDevice::Rx(int ch, uint32 data)
 }
 
 static double
-to_freq(uint64 nsec)
+tsec_to_freq(uint64 tsec)
 {
-	return (double)1.0 / nsec * 1e9;
+	return (double)1_sec / tsec;
 }
 
 // ボーレートを再計算する。
-// CR4(ClkRate) と xc12_ns の変更で呼ぶこと。
+// CR4(ClkRate) と xc12_tsec の変更で呼ぶこと。
 void
 MPSCCDevice::ChangeBaudrate(MPSCCChan& chan)
 {
 	double old_baudrate = chan.baudrate;
 
 	// 誤差を減らすため 12bit 分の時間を基準とする。
-	chan.bit12_ns = chan.xc12_ns * chan.clkrate;
-	chan.baudrate = (double)to_freq(chan.bit12_ns) * 12;
+	chan.bit12_tsec = chan.xc12_tsec * chan.clkrate;
+	chan.baudrate = tsec_to_freq(chan.bit12_tsec) * 12;
 
 	if (loglevel >= 3) {
 		if (chan.baudrate != old_baudrate) {
@@ -838,7 +838,7 @@ MPSCCDevice::SetRxPeriod(MPSCCChan& chan)
 	bit += AdditionalBits(chan, chan.rx_enable);
 	chan.rxframebits = bit;
 
-	rxevent[chan.id]->time = bit * chan.bit12_ns / 12;
+	rxevent[chan.id]->time = bit * chan.bit12_tsec / 12;
 
 	if (loglevel >= 1) {
 		bool old_enable = chan.old_cr3 & MPSCC::CR3_RX_EN;
@@ -859,7 +859,7 @@ MPSCCDevice::SetRxPeriod(MPSCCChan& chan)
 			// そうでなければ(有効→有効なら)、パラメータが変化すれば表示。
 			std::string nsstr;
 			if (loglevel >= 2) {
-				nsstr = string_format(" (%" PRIu64 ")", chan.bit12_ns);
+				nsstr = string_format(" (%" PRIu64 ")", chan.bit12_tsec);
 			}
 			putlogn("Channel %c RX Enable, %.1f bps%s, %u bits/frame",
 				chan.name,
@@ -870,7 +870,7 @@ MPSCCDevice::SetRxPeriod(MPSCCChan& chan)
 		}
 	}
 
-	// パフォーマンス測定用のギミック。
+	// --perf によるパフォーマンス測定用のギミック。
 	// シリアルポートを特定の設定 (本体 5bit、ストップビット 2bit) にすると、
 	// VM 電源オン時から現在までの実時間をログに出力する。NetBSD/OpenBSD の
 	// マルチユーザブートがあらかた終わってログインプロンプトが出る手前の
@@ -903,7 +903,7 @@ MPSCCDevice::SetTxPeriod(MPSCCChan& chan)
 	bit += AdditionalBits(chan, chan.tx_enable);
 	chan.txframebits = bit;
 
-	txevent[chan.id]->time = bit * chan.bit12_ns / 12;
+	txevent[chan.id]->time = bit * chan.bit12_tsec / 12;
 
 	if (loglevel >= 1) {
 		bool old_enable = chan.old_cr5 & MPSCC::CR5_TX_EN;
@@ -924,7 +924,7 @@ MPSCCDevice::SetTxPeriod(MPSCCChan& chan)
 			// そうでなければ(有効→有効なら)、パラメータが変化すれば表示。
 			std::string nsstr;
 			if (loglevel >= 2) {
-				nsstr = string_format(" (%" PRIu64 ")", chan.bit12_ns);
+				nsstr = string_format(" (%" PRIu64 ")", chan.bit12_tsec);
 			}
 			putlogn("Channel %c TX Enable, %.1f bps%s, %u bits/frame",
 				chan.name,
