@@ -27,16 +27,23 @@ class MPUDevice : public Device
 	~MPUDevice() override;
 
 	bool Init() override;
+	void ResetHard(bool poweron) override;
 	void PowerOff() override;
 
 	// 現在実行中の命令の PC を取得
 	virtual uint32 GetPPC() const = 0;
 
+	// 最後に発生した例外ベクタを取得し、同時にクリアする
+	int32 GetAndResetLastVector();
+
  protected:
 	// 1命令実行イベント
 	Event *exec_event {};
 
 	Debugger *debugger {};
+
+	// 最後に発生した例外ベクタ。起きてなければ -1。
+	int32 last_vector {};
 };
 
 // メイン MPU (680x0/88xxx0) 共通部
@@ -73,8 +80,8 @@ class MainMPUDevice : public MPUDevice
 	// MPU クロック [kHz] を取得する。
 	uint GetClockSpeed() const { return clock_khz; }
 
-	// MPU クロック [nsec] を取得する。
-	uint64 GetClock_nsec() const { return clock_nsec; }
+	// MPU クロック [tsec] を取得する。
+	uint64 GetClock_tsec() const { return clock_tsec; }
 
 	// 割り込み発生を MPU に通知
 	virtual void Interrupt(int level) = 0;
@@ -96,7 +103,7 @@ class MainMPUDevice : public MPUDevice
 	uint32 cpu_state {};
 
 	uint clock_khz {};		// MPU クロック [kHz]
-	uint64 clock_nsec {};	// MPU クロック [nsec]
+	uint64 clock_tsec {};	// MPU クロック [tsec]
 
 	bool resetting {};		// リセット処理中フラグ
 
@@ -107,6 +114,6 @@ class MainMPUDevice : public MPUDevice
 	static const char * const rmstr[4];
 };
 
-static inline MainMPUDevice *GetMPUDevice() {
+inline MainMPUDevice *GetMPUDevice() {
 	return Object::GetObject<MainMPUDevice>(OBJ_MPU);
 }
