@@ -59,11 +59,8 @@ MPU64180Device::putlogn(const char *fmt, ...) const
 	int len;
 
 	vt = scheduler->GetVirtTime();
-	len = snprintf(buf, sizeof(buf), "%4u.%03u'%03u'%03u %04x %s ",
-		(uint)(vt / 1000 / 1000 / 1000),
-		(uint)((vt / 1000 / 1000) % 1000),
-		(uint)((vt / 1000) % 1000),
-		(uint)(vt % 1000),
+	len = snprintf(buf, sizeof(buf), "%16s %04x %s ",
+		SecToStr(vt).c_str(),
 		GetPPC(),
 		GetName().c_str());
 
@@ -111,9 +108,9 @@ MPU64180Device::Init()
 	}
 	// 6.144MHz = 162.76… [nsec] であり、変数導入前は 163 をハードコード
 	// して使っていたので、それとの互換性のため四捨五入する。
-	clock_nsec = 1000 * 1000 * 10 / clock_khz;
-	clock_nsec = (clock_nsec + 5) / 10;
-	if (clock_nsec < 1) {
+	clock_tsec = 10_msec / clock_khz;
+	clock_tsec = (clock_tsec + 5) / 10;
+	if (clock_tsec < 1) {
 		xp_clock_item.Err("Clock speed too high");
 		return false;
 	}
@@ -260,7 +257,7 @@ MPU64180Device::EnterNormal()
 	SetTrace(debugger->IsTrace());
 
 	// 3 クロック後から通常サイクル開始? (HD647180.pdf, p23)
-	exec_event->time = 3 * clock_nsec;
+	exec_event->time = 3 * clock_tsec;
 	scheduler->RestartEvent(exec_event);
 }
 
@@ -284,7 +281,7 @@ MPU64180Device::EnterWakeup()
 {
 	// 復帰処理のため一旦 Wakeup へ。
 	SetExec(ToEventCallback(&MPU64180Device::ExecWakeup));
-	exec_event->time = 3 * clock_nsec;
+	exec_event->time = 3 * clock_tsec;
 
 	scheduler->StartEvent(exec_event);
 }
@@ -604,11 +601,10 @@ MPU64180Device::MonitorScreenIO(Monitor *, TextScreen& screen)
 	y++;
 	for (int ch = 0; ch < timer.size(); ch++) {
 		auto& t = timer[ch];
-		uint64 reload_nsec = t.reload * clock_nsec * 20;
-		screen.Print(4, y++, "Timer%u: Count=$%04x Reload=$%04x(%6u.%03u usec)",
+		uint64 reload_tsec = t.reload * clock_tsec * 20;
+		screen.Print(4, y++, "Timer%u: Count=$%04x Reload=$%04x(%10.3f usec)",
 			ch, t.count, t.reload,
-			(uint)(reload_nsec / 1000),
-			(uint)(reload_nsec % 1000));
+			(double)reload_tsec / 1000);
 	}
 	screen.Print(0, y++, "18H FRC  = $%02x", PeekFRC());
 
