@@ -148,6 +148,25 @@ MPU680x0Device::Init()
 		break;
 	}
 
+	// 機種ごとの NetBSD カーネルエントリポイント。
+	// 履歴で TRAP #0 がシステムコールかどうかの判定に使う。
+	switch (gMainApp.GetVMType()) {
+	 case VMType::LUNA1:
+		netbsd_entrypoint = 0xc000;
+		break;
+	 case VMType::X68030:
+		netbsd_entrypoint = 0x0022;
+		break;
+	 case VMType::NEWS:
+		netbsd_entrypoint = 0x0000;
+		break;
+	 case VMType::VIRT68K:
+		netbsd_entrypoint = 0x2000;
+		break;
+	 default:
+		__unreachable();
+	}
+
 	interruptdev = GetInterruptDevice();
 	vectortable = GetVectorTable();
 
@@ -163,7 +182,7 @@ MPU680x0Device::Init()
 	intr_event = evman->Regist(this,
 		ToEventCallback(&MPU680x0Device::InterruptCallback),
 		GetName() + " Interrupt");
-	intr_event->time = 3 * clock_nsec;
+	intr_event->time = 3 * clock_tsec;
 
 	// レジスタモニタの行数。
 	int height = 9;
@@ -215,7 +234,7 @@ MPU680x0Device::ResetHard(bool poweron)
 	// 起動するまでに時間がかかるというところを都合よく真似ておく。
 
 	exec_event->SetCallback(&MPU680x0Device::ResetCallback);
-	exec_event->time = 520 * clock_nsec;
+	exec_event->time = 520 * clock_tsec;
 	exec_event->SetName(GetName() + " Reset");
 	scheduler->RestartEvent(exec_event);
 }
@@ -238,7 +257,7 @@ MPU680x0Device::ResetCallback(Event *ev)
 	// 以降は通常走行。
 	if (cpu_state == CPU_STATE_NORMAL) {
 		exec_event->SetCallback(exec_short);
-		exec_event->time = cycle * clock_nsec;
+		exec_event->time = cycle * clock_tsec;
 		exec_event->SetName(GetName() + " Execute");
 		scheduler->RestartEvent(exec_event);
 	} else {
@@ -368,7 +387,7 @@ MPU680x0Device::InterruptCallback(Event *ev)
 		// STOP 状態だったらここでイベントを開始する
 		if (cpu_state == CPU_STATE_STOP) {
 			// STOP から抜ける時間?
-			exec_event->time = 1 * clock_nsec;
+			exec_event->time = 1 * clock_tsec;
 			scheduler->StartEvent(exec_event);
 		}
 	}
@@ -403,7 +422,6 @@ MPU680x0Device::SetFLineCallback(bool (*callback)(MPU680x0Device *, void*),
 void
 MPU680x0Device::ops_reset()
 {
-	auto mainbus = GetMainbusDevice();
 	mainbus->ResetByMPU();
 }
 
@@ -591,7 +609,11 @@ MPU68030Device::MPU68030Device()
 	// ATC モニター
 	atc_monitor = gMonitorManager->Regist(ID_MONITOR_MPUATC, this);
 	atc_monitor->SetCallback(&MPU68030Device::MonitorScreenATC);
+#if defined(M68030_CUSTOM_ATC)
 	atc_monitor->SetSize(114, m68030ATCTable::LINES + 6);
+#else
+	atc_monitor->SetSize(45, m68030ATCTable::LINES + 2);
+#endif
 
 	// キャッシュモニター
 	cache_monitor = gMonitorManager->Regist(ID_MONITOR_MPUCACHE, this);
@@ -612,7 +634,18 @@ MPU68030Device::SetLogLevel(int loglevel_)
 	atc.SetLogLevel(loglevel_);
 }
 
-static int
+void
+MPU68030Device::ResetHard(bool poweron)
+{
+	inherited::ResetHard(poweron);
+
+	if (poweron) {
+		// 電源(再)投入で統計情報もクリア。
+		atc.ResetStat();
+	}
+}
+
+static int __unused
 sort_atc(const void *a, const void *b)
 {
 	const uint32 *ua = (const uint32 *)a;
@@ -728,10 +761,13 @@ MPU68030Device::MonitorScreenMMU(TextScreen& screen, int y, m68kreg& tmp)
 void
 MPU68030Device::MonitorScreenATC(Monitor *, TextScreen& screen)
 {
-	m68030ATCTable *table;
-
 	screen.Clear();
 
+	bool atc_enable = mmu_tc.e;
+
+#if defined(M68030_CUSTOM_ATC)
+	m68030ATCTable_Custom *table;
+
 	struct {
 		int fc;
 		const char *name;
@@ -763,7 +799,7 @@ MPU68030Device::MonitorScreenATC(Monitor *, TextScreen& screen)
 			int idx = sbuf[i * 2 + 1];
 			m68030ATCLine& a = table->line[idx];
 			TA attr;
-			if (a.IsInvalid()) {
+			if (a.IsInvalid() || (atc_enable == false)) {
 				attr = TA::Disable;
 			} else {
 				attr = TA::Normal;
@@ -827,12 +863,80 @@ MPU68030Device::MonitorScreenATC(Monitor *, TextScreen& screen)
 		"Note: The real 68030 ATC is single FC-mixed 22-entries. "
 		"This ATC with FC-separated %u-entries is by nono.",
 		m68030ATCTable::LINES);
+#else
+	m68030ATCTable_Motorola *table = atc.table.get();
+	static const char fcstr[] =
+		"--\0\0"	// 0
+		"UD\0\0"	// 1
+		"UP\0\0"	// 2
+		"--\0\0"	// 3
+		"--\0\0"	// 4
+		"SD\0\0"	// 5
+		"SP\0\0"	// 6
+		"--";		// 7
+
+	//                 00 [00] SD(5).01234'567 01234'567 ----
+	screen.Puts(0, 0, "No Idx  FC    LAddr     PAddr     Flag   Hit%");
+	uint y = 1;
+#if defined(ATC_ORDER128)
+	uint128 order_ = table->order;
+#endif
+	for (uint i = 0; i < m68030ATCTable::LINES; i++) {
+#if defined(ATC_ORDER128)
+		uint n = (uint)order_ & 0x1f;
+		order_ >>= 5;
+#else
+		uint n = table->order[i];
+#endif
+		const m68030ATCLine *a = &table->line[n];
+		TA attr;
+		if (a->IsInvalid() || (atc_enable == false)) {
+			attr = TA::Disable;
+		} else {
+			attr = TA::Normal;
+		}
+		uint fc = a->GetFC();
+		screen.Print(0, y++, attr,
+			"%2d [%02d] %u(%s).%06x'00 %06x'00 %c%c%c%c",
+			i,
+			n,
+			fc, &fcstr[fc * 4],
+			(a->GetLAddr() >> 8),
+			(a->GetPAddr() >> 8),
+			(a->IsBusError() ? 'B' : '-'),
+			(a->IsCInhibit() ? 'C' : '-'),
+			(a->IsWProtect() ? 'P' : '-'),
+			(a->IsModified() ? 'M' : '-'));
+	}
+
+	// ATC ヒット/ミス率、ついでに TT のマッチ率も表示。
+	std::array<double, m68030ATCTable::LINES + 1> rate {};
+	double ttrate {};
+	// total は ATC を検索した回数。
+	uint64 total = table->atcstat.total - table->atcstat.tthit;
+	if (total != 0) {
+		uint i;
+		for (i = 0; i < m68030ATCTable::LINES; i++) {
+			rate[i] = (double)table->stat_atchit[i] / total * 100;
+		}
+		rate[i] = (double)table->atcstat.miss / total * 100;
+		ttrate = (double)table->atcstat.tthit / total * 100;
+	}
+	y = 1;
+	for (auto r : rate) {
+		screen.Print(38, y++, "%6.2f%%", r);
+	}
+	y--;
+	screen.Print(15, y, "(TT Hit:%5.2f%%)", ttrate);
+	screen.Puts(31,  y, "ATCMiss");
+#endif
 }
 
 // 統計情報を更新 (Syncer から呼ばれる)
 void
 MPU68030Device::CalcStat()
 {
+#if defined(M68030_CUSTOM_ATC)
 	// ATC のヒット率。
 	for (auto& table : atc.tables) {
 		// ここはロックなしでやってしまう
@@ -854,6 +958,7 @@ MPU68030Device::CalcStat()
 			}
 		}
 	}
+#endif
 
 	// キャッシュのヒット率。
 	icache->CalcStat();
