@@ -314,6 +314,7 @@ class MPU680x0Device : public MainMPUDevice
 	int  ExceptionReset();
 	void ExceptionBuserr(uint vector);
 	uint64 ExceptionInterrupt();
+	void ExceptionTrap0();
 	void ExceptionTrap15();
 	void ExceptionFLine();
 	void ExceptionFP(uint vector);
@@ -438,6 +439,10 @@ class MPU680x0Device : public MainMPUDevice
 	// 例外履歴のみ
 	BranchHistory_m680x0 exhist { OBJ_MPU_EXHIST };
 
+	// NetBSD カーネルのエントリポイント。
+	// TRAP#0 の履歴でシステムコールを判定するのに使う。
+	uint32 netbsd_entrypoint {};
+
 	// 割り込みイベント
 	Event *intr_event {};
 
@@ -466,6 +471,7 @@ class MPU68030Device : public MPU680x0Device
 	~MPU68030Device() override;
 
 	void SetLogLevel(int loglevel_) override;
+	void ResetHard(bool poweron) override;
 
 	uint64 GetSRP()  const { return reg.srp.q; }
 	uint32 GetSRPh() const { return reg.srp.h; }
@@ -491,11 +497,12 @@ class MPU68030Device : public MPU680x0Device
 	void ops_mmu30() override;
 	void ops_mmu40_pflush() override;
 	uint32 get_fc();
-	void mmu_op_illg2();
-	void mmu_op_pflush();
-	void mmu_op_pflush_ea();
-	void mmu_op_pload();
-	void mmu_op_ptest();
+	void ops_mmu30_illg2();
+	void ops_mmu30_pflusha();
+	void ops_mmu30_pflush();
+	void ops_mmu30_pflush_ea();
+	void ops_mmu30_pload();
+	void ops_mmu30_ptest();
 
 	// バスアクセス
 	uint32 fetch_2() override;
@@ -547,6 +554,7 @@ class MPU68030Device : public MPU680x0Device
 class MPU68040Device : public MPU680x0Device
 {
 	using inherited = MPU680x0Device;
+	friend class WXPageTable68040Window;
 
  public:
 	MPU68040Device();
@@ -621,6 +629,6 @@ class MPU68040Device : public MPU680x0Device
 extern MPU680x0Device *NewMPU680x0Device();
 
 // これを呼びたい人は mpu を持ってるはず。
-static inline MPU680x0Device *GetMPU680x0Device(Device *mpu_) {
+inline MPU680x0Device *GetMPU680x0Device(Device *mpu_) {
 	return dynamic_cast<MPU680x0Device*>(mpu_);
 }
