@@ -148,7 +148,7 @@ MPU88xx0Device::ResetHard(bool poweron)
 	// おく。
 
 	exec_event->SetCallback(&MPU88xx0Device::ResetCallback);
-	exec_event->time = (8 + 256) * clock_nsec;
+	exec_event->time = (8 + 256) * clock_tsec;
 	exec_event->SetName(GetName() + " Reset");
 	scheduler->RestartEvent(exec_event);
 }
@@ -163,10 +163,9 @@ MPU88xx0Device::ResetCallback(Event *ev)
 
 	// 例外履歴に記録 (例外発生はブランチ履歴にも記録)
 	// リセット例外も発生時の XIP を記録する。(LUNA-88K の PROM 1.20)
+	last_vector = 0;
 	exhist.AddEntry(reg.xip | 1, 0, 0xfc000000 | 0);
 	brhist.AddEntry(reg.xip | 1, 0, 0xfc000000 | 0);
-	// デバッガに通知 (例外ブレーク用)
-	debugger->NotifyExceptionMain(0);
 
 	// 内部の例外状態をクリア
 	resetting = false;
@@ -218,7 +217,7 @@ MPU88xx0Device::ResetCallback(Event *ev)
 	// 以降は通常走行
 	int cycle = used_cycle - cycle_start;
 	exec_event->SetCallback(exec_normal);
-	exec_event->time = cycle * clock_nsec;
+	exec_event->time = cycle * clock_tsec;
 	exec_event->SetName(GetName() + " Execute");
 	scheduler->StartEvent(exec_event);
 }
