@@ -59,7 +59,7 @@ class MPU88xx0Device : public MainMPUDevice, private M88100
 	}
 
 	// アクセスウェイト [nsec] を加算。m88200 が呼ぶ。
-	void AddWait(uint32 nsec) {
+	void AddWait(uint64 nsec) {
 		buswait += nsec;
 	}
 
@@ -232,6 +232,6 @@ OP_PROTO(illegal);
 };
 
 // これを呼びたい人は mpu を持ってるはず。
-static inline MPU88xx0Device *GetMPU88xx0Device(Device *mpu_) {
+inline MPU88xx0Device *GetMPU88xx0Device(Device *mpu_) {
 	return dynamic_cast<MPU88xx0Device*>(mpu_);
 }
