@@ -91,6 +91,6 @@ class NereidBoardDevice : public IODevice
 	std::unique_ptr<RTL8019ASDevice> net /*{}*/;
 };
 
-static inline NereidDevice *GetNereidDevice() {
+inline NereidDevice *GetNereidDevice() {
 	return Object::GetObject<NereidDevice>(OBJ_NEREID);
 }
