@@ -18,7 +18,7 @@ NewsfbDevice::NewsfbDevice()
 	console.Init(80, 32, TextScreen::Console);
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_ROMCONS, this);
-	monitor->func = ToMonitorCallback(&NewsfbDevice::MonitorUpdate);
+	monitor->SetCallback(&NewsfbDevice::MonitorScreen);
 	monitor->SetSize(console.GetCol(), console.GetRow());
 }
 
@@ -49,7 +49,7 @@ NewsfbDevice::Putc(int ch)
 }
 
 void
-NewsfbDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+NewsfbDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	int row = console.GetRow();
 	int col = console.GetCol();
