@@ -42,6 +42,6 @@ class NMIDevice : public Device
 	Event *event {};
 };
 
-static inline NMIDevice *GetNMIDevice() {
+inline NMIDevice *GetNMIDevice() {
 	return Object::GetObject<NMIDevice>(OBJ_NMI);
 }
