@@ -28,6 +28,6 @@ class NopIODevice : public IODevice
 	busdata Peek1(uint32 addr) override;
 };
 
-static inline NopIODevice *GetNopIODevice() {
+inline NopIODevice *GetNopIODevice() {
 	return Object::GetObject<NopIODevice>(OBJ_NOPIO);
 }
