@@ -37,6 +37,6 @@ class PartialRAMDevice : public IODevice
 	IODevice *nopdev {};
 };
 
-static inline PartialRAMDevice *GetPartialRAMDevice() {
+inline PartialRAMDevice *GetPartialRAMDevice() {
 	return Object::GetObject<PartialRAMDevice>(OBJ_PARTIAL_RAM);
 }
