@@ -113,7 +113,7 @@ i8255Device::PokePort(uint32 offset, uint32 data)
 // 共通部分を表示。
 // 戻り値は表示を終えた次の行。
 int
-i8255Device::MonitorUpdateCommon(TextScreen& screen, int y)
+i8255Device::MonitorScreenCommon(TextScreen& screen, int y)
 {
 	// Control = $xx
 	//  GroupA (PortA,PortCH) Mode: 0(Basic I/O)
@@ -372,7 +372,7 @@ PIO0Device::PIO0Device()
 
 	// PIO0/PIO1
 	monitor = gMonitorManager->Regist(ID_MONITOR_PIO, this);
-	monitor->func = ToMonitorCallback(&PIO0Device::MonitorUpdate);
+	monitor->SetCallback(&PIO0Device::MonitorScreen);
 	monitor->SetSize(76, 15);
 }
 
@@ -510,7 +510,7 @@ PIO0Device::PeekPort(uint32 offset)
 
 // PIO0 が PIO0/PIO1 のモニタ両方を担当する。
 void
-PIO0Device::MonitorUpdate(Monitor *, TextScreen& screen)
+PIO0Device::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	int y;
 
@@ -518,7 +518,7 @@ PIO0Device::MonitorUpdate(Monitor *, TextScreen& screen)
 
 	// PIO0
 	screen.Puts(0, 0, "PIO0 (BaseAddr: $49000000)");
-	y = MonitorUpdateCommon(screen, 1);
+	y = MonitorScreenCommon(screen, 1);
 
 	// PIO0 固有部
 	uint32 pa = GetPA();
@@ -552,7 +552,7 @@ PIO0Device::MonitorUpdate(Monitor *, TextScreen& screen)
 
 	// PIO1 移譲
 	y++;
-	pio1->MonitorUpdatePIO1(screen, y);
+	pio1->MonitorScreenPIO1(screen, y);
 }
 
 // PortA (DIP-SW 1) 読み込み
@@ -821,12 +821,12 @@ PIO1Device::PeekPort(uint32 offset)
 
 // PIO0 の下請け。
 void
-PIO1Device::MonitorUpdatePIO1(TextScreen& screen, int y)
+PIO1Device::MonitorScreenPIO1(TextScreen& screen, int y)
 {
 	screen.Puts(0, y++, "PIO1 (BaseAddr: $4d000000)");
 
 	// 共通部分
-	y = MonitorUpdateCommon(screen, y++);
+	y = MonitorScreenCommon(screen, y++);
 
 	// PIO1 固有部
 	screen.Print(1, y++, "PortA(LCDDATA)=$%02x", lcd->Peek());
