@@ -56,12 +56,12 @@ class PROMDevice : public ROMDevice
 	uint romver {};
 };
 
-static inline PROM0Device *GetPROM0Device() {
+inline PROM0Device *GetPROM0Device() {
 	return Object::GetObject<PROM0Device>(OBJ_PROM_BOOT);
 }
 
 // PROM(現物)と ROMEMU の共通層である ROMDevice を返す。
 // 区別が必要なら呼び出し側でもう一度 dynamic_cast<> すること。
-static inline ROMDevice *GetPROMDevice() {
+inline ROMDevice *GetPROMDevice() {
 	return Object::GetObject<ROMDevice>(OBJ_PROM);
 }
