@@ -26,7 +26,7 @@ RP5C15Device::RP5C15Device()
 	use_localtime = true;
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_RTC, this);
-	monitor->func = ToMonitorCallback(&RP5C15Device::MonitorUpdate);
+	monitor->SetCallback(&RP5C15Device::MonitorScreen);
 	monitor->SetSize(38, 22);
 }
 
@@ -267,7 +267,7 @@ RP5C15Device::PokePort(uint32 offset, uint32 data)
 }
 
 void
-RP5C15Device::MonitorUpdate(Monitor *, TextScreen& screen)
+RP5C15Device::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	int x = 18;
 	int y = 0;
