@@ -125,7 +125,7 @@ class RTCDevice : public IODevice
 	void Callback(Event *);
 
 	// イベント間隔
-	const uint period = 31.25_msec;
+	const uint64 period = 31.25_msec;
 
 	// システムクロックが刻んでいる時刻
 	uint64 stime {};
@@ -136,6 +136,6 @@ class RTCDevice : public IODevice
 	Event *event {};
 };
 
-static inline RTCDevice *GetRTCDevice() {
+inline RTCDevice *GetRTCDevice() {
 	return Object::GetObject<RTCDevice>(OBJ_RTC);
 }
