@@ -2119,7 +2119,7 @@ RTL8019ASDevice::TXEvent(Event *ev)
 
 	// 転送にかかった時間を模しておく。
 	// 時間は適当。10Mbps なので 1バイトあたり 1usec とする。
-	tx_event->time = count * 1_usec;
+	tx_event->time = usec_to_tsec(count);
 	scheduler->StartEvent(tx_event);
 }
 
@@ -2267,7 +2267,7 @@ RTL8019ASDevice::RXCopy(Event *ev, uint remain)
 
 	// 転送にかかった時間を模しておく。
 	// 時間は適当。10Mbps なので 1バイトあたり 1usec とする。
-	ev->time = count * 1_usec;
+	ev->time = usec_to_tsec(count);
 	scheduler->RestartEvent(ev);
 }
 
