@@ -45,8 +45,8 @@ SIODevice::SIODevice()
 
 	// 153.6kHz = 6.510416...usec / bit;
 	// 12bit = 78.125usec
-	mpscc.chan[0].xc12_ns = 78.125_usec;
-	mpscc.chan[1].xc12_ns = 78.125_usec;
+	mpscc.chan[0].xc12_tsec = 78.125_usec;
+	mpscc.chan[1].xc12_tsec = 78.125_usec;
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_SIO, this);
 	monitor->SetCallback(&SIODevice::MonitorScreen);
