@@ -73,6 +73,6 @@ class SIODevice : public MPSCCDevice
 	static const char * const srnames[16];
 };
 
-static inline SIODevice *GetSIODevice() {
+inline SIODevice *GetSIODevice() {
 	return Object::GetObject<SIODevice>(OBJ_MPSCC);
 }
