@@ -8,7 +8,7 @@
 // サウンドレンダラ
 //
 
-// vtime / BLK_NSEC をブロック時刻と呼ぶことにする。
+// vtime / BLK_TSEC をブロック時刻と呼ぶことにする。
 //
 // 各サウンドトラックは 2 (=NSRCBLKS) ブロック分のバッファを持つ。
 // ブロック境界の 000'000_nsec ちょうどにソースデバイスとサウンドレンダラの
@@ -166,7 +166,7 @@ SoundRenderer::Init()
 	syncer = GetSyncer();
 
 	// トラック合成用バッファ。(1ブロック分)
-	auto mixer_frames_per_blk = (uint64)mixerfreq * BLK_NSEC / 1_sec;
+	auto mixer_frames_per_blk = (uint64)mixerfreq * BLK_TSEC / 1_sec;
 	mixer_samples_per_blk = FRAMES_TO_SAMPLES(mixer_frames_per_blk);
 	mixbuf.reset(new(std::nothrow) int16[mixer_samples_per_blk]);
 	if (mixbuf == NULL) {
@@ -215,7 +215,7 @@ SoundRenderer::Reconfig(bool startup)
 		need_resize = true;
 	}
 
-	auto out_frames_per_blk = (uint64)outfreq * BLK_NSEC / 1_sec;
+	auto out_frames_per_blk = (uint64)outfreq * BLK_TSEC / 1_sec;
 	out_samples_per_blk = FRAMES_TO_SAMPLES(out_frames_per_blk);
 
 	if (need_resize) {
@@ -270,7 +270,7 @@ SoundRenderer::StartPlay(SoundTrack *track)
 	if (play_event->IsRunning() == false) {
 		// ミキサーイベントが停止してたらイベントを起動する。
 		// 最初の1回は、ブロック境界になるようにする。
-		play_event->time = BLK_NSEC - (scheduler->GetVirtTime() % BLK_NSEC);
+		play_event->time = BLK_TSEC - (scheduler->GetVirtTime() % BLK_TSEC);
 
 		scheduler->StartEvent(play_event);
 		syncer->NotifySoundRunning(true);
@@ -309,7 +309,7 @@ SoundRenderer::Callback(Event *event)
 
 	// ブロック境界を繰り上がったところで呼ばれているので
 	// 処理したいのは一つ前のブロック。
-	uint64 vseq = (scheduler->GetVirtTime() / BLK_NSEC) - 1;
+	uint64 vseq = (scheduler->GetVirtTime() / BLK_TSEC) - 1;
 
 	// 裏(レンダラ)スレッドに通知するだけ。
 	// キューが一杯ならロストするだけ (だけ?)。
@@ -320,7 +320,7 @@ SoundRenderer::Callback(Event *event)
 	}
 
 	// 次のイベント。
-	event->time = BLK_NSEC;
+	event->time = BLK_TSEC;
 	scheduler->StartEvent(event);
 }
 
