@@ -32,7 +32,7 @@ class Sound
 
 	// 1ブロックの時間。
 	// ADPCM の制約からこれ以上小さくは出来ない(し大きくする必要もない)。
-	static constexpr uint64 BLK_NSEC = 40_msec;
+	static constexpr uint64 BLK_TSEC = 40_msec;
 
 	// サウンドソースのブロック数。
 	// ダブルバッファ方式なので 2。
@@ -192,6 +192,6 @@ class SoundRenderer : public ThreadDevice, private Sound
 	Syncer *syncer {};
 };
 
-static inline SoundRenderer *GetSoundRenderer() {
+inline SoundRenderer *GetSoundRenderer() {
 	return Object::GetObject<SoundRenderer>(OBJ_SOUND_RENDERER);
 }
