@@ -99,8 +99,11 @@ SPCDevice::Init()
 	// 入力クロックは機種によって異なる。
 	// X68k は 5MHz が入っている。
 	// LUNA-I はおそらく 6.144MHz だと思われる。LUNA-88K は未確認。
-	const ConfigItem& item = gConfig->Find("!spc-tCLF");
-	t_CLF = item.AsInt();
+	if (vmtype == VMType::X68030) {
+		t_CLF = 200_nsec;
+	} else {
+		t_CLF = 163_nsec;
+	}
 
 	// アクセスウェイト
 	if (vmtype == VMType::X68030) {
@@ -1277,14 +1280,14 @@ SPCDevice::SelectCommand()
 		// 必ずバスの使用権を得る。
 
 		// バスフリーから規定時間後に SEL (と DB* と ATN) を上げる。
-		uint64 t_ARB  = 32 * t_CLF - 60;
-		uint64 t_AWSL = 40;	// 適当に中間
+		uint64 t_ARB  = 32 * t_CLF - 60_nsec;
+		uint64 t_AWSL = 40_nsec;	// 適当に中間
 		CallAfter(Arbitration1, "SPC Arbitration", wait + t_ARB + t_AWSL);
 	} else {
 		// アービトレーションなしの場合
 
 		// バスフリーから規定時間後に SEL (と DB*) を上げる。
-		uint64 t_IDSL = 11 * t_CLF - 80;
+		uint64 t_IDSL = 11 * t_CLF - 80_nsec;
 		CallAfter(Selection1, "SPC Selection", wait + t_IDSL);
 	}
 }
@@ -1311,8 +1314,8 @@ SPCDevice::Arbitration1(Event *ev)
 	}
 	AssertSEL();
 
-	uint64 t_SIDA = 11 * t_CLF - 30;
-	uint64 t_IDBH = 2 * t_CLF - 80;
+	uint64 t_SIDA = 11 * t_CLF - 30_nsec;
+	uint64 t_IDBH = 2 * t_CLF - 80_nsec;
 	CallAfter(Arbitration2, "SPC Arbitration2", t_SIDA + t_IDBH);
 }
 
