@@ -69,6 +69,6 @@ class SRAMDevice : public IODevice
 	static std::array<uint8, 0x58> initialdata;
 };
 
-static inline SRAMDevice *GetSRAMDevice() {
+inline SRAMDevice *GetSRAMDevice() {
 	return Object::GetObject<SRAMDevice>(OBJ_SRAM);
 }
