@@ -115,6 +115,6 @@ class SSGDevice : public IODevice
 	Monitor *monitor {};
 };
 
-static inline SSGDevice *GetSSGDevice() {
+inline SSGDevice *GetSSGDevice() {
 	return Object::GetObject<SSGDevice>(OBJ_SSG);
 }
