@@ -166,6 +166,6 @@ class Syncer : public Device
 	Event *sync_event {};
 };
 
-static inline Syncer *GetSyncer() {
+inline Syncer *GetSyncer() {
 	return Object::GetObject<Syncer>(OBJ_SYNCER);
 }
