@@ -81,6 +81,6 @@ class SysportDevice : public IODevice
 	VideoCtlrDevice *videoctlr {};
 };
 
-static inline SysportDevice *GetSysportDevice() {
+inline SysportDevice *GetSysportDevice() {
 	return Object::GetObject<SysportDevice>(OBJ_SYSPORT);
 }
