@@ -110,7 +110,7 @@ end_perf_func()
 {
 	sw.Stop();
 
-	uint64 usec = sw.Elapsed_nsec() / 1000U;
+	uint64 usec = nsec_to_usec(sw.Elapsed_nsec());
 	printf("%6.2f times/usec\n", (double)perf_count / usec);
 }
 
