@@ -443,7 +443,7 @@ VideoCtlrDevice::ContrastCallback(Event *ev)
 		// 下がる時は (initial - target) * exp(-t / RC)
 		// 上がる時は (target - initial) * (1 - exp(-t / RC))
 		uint64 now = scheduler->GetVirtTime();
-		float t = (float)(now - contrast_time0) / 1e9;
+		float t = (float)(now - contrast_time0) / 1_sec;
 		float e = std::exp(-t / RC);
 		float n;
 		if (initial_contrast > target_contrast) {
@@ -650,7 +650,7 @@ VideoCtlrDevice::RenderContrast(BitmapRGBX& dst, const BitmapRGBX& src)
 		sw.Stop();
 		perf_total += sw.Elapsed_nsec();
 		if (++perf_count % 100 == 0) {
-			printf("%" PRIu64 " usec\n", perf_total / perf_count / 1000);
+			printf("%" PRIu64 " usec\n", nsec_to_usec(perf_total) / perf_count);
 		}
 #endif
 	}
