@@ -185,6 +185,6 @@ class VideoCtlrDevice : public IODevice, public VideoCtlr
 	VideoRenderer *renderer {};
 };
 
-static inline VideoCtlrDevice *GetVideoCtlrDevice() {
+inline VideoCtlrDevice *GetVideoCtlrDevice() {
 	return Object::GetObject<VideoCtlrDevice>(OBJ_VIDEOCTLR);
 }
