@@ -310,7 +310,7 @@ VirtIODevice::PeekPort(uint32 offset)
 
 // 下請け、デバイス情報部分。
 int
-VirtIODevice::MonitorUpdateDev(TextScreen& screen, int y) const
+VirtIODevice::MonitorScreenDev(TextScreen& screen, int y) const
 {
 // 0         1         2         3         4         5         6         7
 // 012345678901234567890123456789012345678901234567890123456789012345678901234
@@ -348,7 +348,7 @@ VirtIODevice::MonitorUpdateDev(TextScreen& screen, int y) const
 
 // 下請け、VirtQueue 1本の概要。
 int
-VirtIODevice::MonitorUpdateVirtQueue(TextScreen& screen, int y,
+VirtIODevice::MonitorScreenVirtQueue(TextScreen& screen, int y,
 	const VirtQueue& q) const
 {
 // 0         1         2         3         4         5         6         7
@@ -397,7 +397,7 @@ VirtIODevice::MonitorUpdateVirtQueue(TextScreen& screen, int y,
 
 // 下請け、VirtQDesc テーブル。(デバッグ用)
 int
-VirtIODevice::MonitorUpdateVirtQDesc(TextScreen& screen, int y,
+VirtIODevice::MonitorScreenVirtQDesc(TextScreen& screen, int y,
 	const VirtQueue& q) const
 {
 	int x0;
