@@ -29,7 +29,7 @@ VirtIOEntropyDevice::VirtIOEntropyDevice(uint slot_)
 	msgid = MessageID::VIRTIO_ENTROPY_DONE;
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_VIRTIO_ENTROPY, this);
-	monitor->func = ToMonitorCallback(&VirtIOEntropyDevice::MonitorUpdate);
+	monitor->SetCallback(&VirtIOEntropyDevice::MonitorScreen);
 	monitor->SetSize(MONITOR_WIDTH, 2 + 4 * 1 + num_max + 3);
 }
 
@@ -39,17 +39,17 @@ VirtIOEntropyDevice::~VirtIOEntropyDevice()
 }
 
 void
-VirtIOEntropyDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+VirtIOEntropyDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	int y = 0;
 
 	screen.Clear();
 
-	y = MonitorUpdateDev(screen, y);
+	y = MonitorScreenDev(screen, y);
 	y++;
-	y = MonitorUpdateVirtQueue(screen, y, vqueues[0]);
+	y = MonitorScreenVirtQueue(screen, y, vqueues[0]);
 	y++;
-	y = MonitorUpdateVirtQDesc(screen, y, vqueues[0]);
+	y = MonitorScreenVirtQDesc(screen, y, vqueues[0]);
 }
 
 // ディスクリプタを一つ処理する。
