@@ -250,7 +250,8 @@ VirtIONetDevice::RxEvent(Event *ev)
 	uint16 avail_idx = ReadLE16(q->driver + 2);
 	if (q->last_avail_idx == avail_idx) {
 		event->time = 500_usec;
-		putlog(2, "%s: wait %u usec", __func__, (uint)(event->time / 1_usec));
+		putlog(2, "%s: wait %u usec", __func__,
+			(uint)tsec_to_usec(event->time));
 		scheduler->RestartEvent(event);
 		return;
 	}
