@@ -27,7 +27,7 @@ class VirtIONetDevice : public VirtIODevice, public IHWAddrFilter
 	int HWAddrFilter(const MacAddr& dstaddr) const override;
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	void QueueReadyChanged(VirtQueue *) override;
 	void ProcessDesc(VirtIOReq&) override;
