@@ -33,7 +33,7 @@ class VirtIOSCSIDevice : public VirtIODevice
 	void GetAccess(std::array<uint32, 16> *dst) const { *dst = access; }
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	void ProcessDesc(VirtIOReq&) override;
 
