@@ -37,14 +37,12 @@ class VM
 	// スレッド開始
 	bool StartThread();
 
-	// 設定の適用
-	bool Apply();
-
 	// VM 名取得 (ウィンドウタイトル用)
 	const char *GetVMName() const { return vmname; }
 
  protected:
 	std::unique_ptr<Device> pDebugger {};
+	std::unique_ptr<Object> pEventManager {};
 	std::unique_ptr<Device> pKeyboard {};
 	std::unique_ptr<Device> pMainbus {};
 	std::unique_ptr<Device> pMPU {};
