@@ -25,7 +25,7 @@ class WXBitmapPanel : public wxPanel
 		const wxPoint& position = wxDefaultPosition,
 		const wxSize& size = wxDefaultSize,
 		long style = wxTAB_TRAVERSAL);
-	virtual ~WXBitmapPanel() override;
+	~WXBitmapPanel() override;
 
 	// 背景色を設定する
 	void SetBitmapBGColor(Color c);
