@@ -47,9 +47,6 @@ class WXLCDWindow : public WXSubWindow
  public:
 	explicit WXLCDWindow(wxWindow *parent);
 	~WXLCDWindow() override;
-
- private:
-	WXLCDPanel *panel {};
 };
 
 // モニタの LCD キャラクタ部パネル
@@ -80,7 +77,11 @@ class WXLCDMonitor : public WXSubWindow
 	explicit WXLCDMonitor(wxWindow *parent);
 	~WXLCDMonitor() override;
 
+	void FontChanged() override;
+	bool Layout() override;
+
  private:
 	WXMonitorPanel *monpanel {};
 	WXLCDCharPanel *chrpanel {};
+	WXBitmapPanel *space {};
 };
