@@ -20,6 +20,7 @@
 #include "wxmainview.h"
 #include "wxmonitor.h"
 #include "wxmpumonitor.h"
+#include "wxpagetablemonitor.h"
 #include "wxpalettemonitor.h"
 #include "wxromwindow.h"
 #include "wxsoftkey.h"
@@ -442,6 +443,7 @@ WXMainFrame::WXMainFrame(wxWindow *parent)
 	wxMenu *menuMPU = new wxMenu();
 	AppendIf(menuMPU, ID_MONITOR_MPUREG,		_("&Registers"));
 	AppendIf(menuMPU, ID_MONITOR_MPUATC,		  "&ATC");
+	AppendIf(menuMPU, ID_SUBWIN_MPUPT,			_("&Page Table"));
 	AppendIf(menuMPU, ID_MONITOR_MPUCACHE,		_("&Caches"));
 	AppendIf(menuMPU, ID_MONITOR_INTERRUPT,		_("&Interrupts"));
 	AppendIfSeparator(menuMPU, VMCap::M88K);
@@ -2194,6 +2196,23 @@ WXMainFrame::DoWindow(int id, bool enable)
 			break;
 		 }
 
+		 case ID_SUBWIN_MPUPT:
+		 {
+			wxString name = MPUName() + " " + _("Page Table");
+			if (MPUName() == "MC68030") {
+				try {
+					windows[id].reset(new WXPageTable68030Window(this, name));
+				} catch (...) { }
+			} else if (MPUName() == "MC68040") {
+				try {
+					windows[id].reset(new WXPageTable68040Window(this, name));
+				} catch (...) { }
+			} else {
+				// not supported
+			}
+			break;
+		 }
+
 		 case ID_SUBWIN_NEWSIO:
 			try {
 				windows[id].reset(new WXScrollMonitorWindow(this,
