@@ -12,7 +12,6 @@
 #include "wxmainframe.h"
 #include "wxuimessage.h"
 #include "config.h"
-#include "device.h"
 #include "keyboard.h"
 #include "renderer.h"
 #include <wx/event.h>
@@ -88,8 +87,8 @@ WXMainView::WXMainView(wxWindow *parent)
 	// 実画面 (ウィンドウの大きさ)
 	DoResize(screen_scale);
 
-	// 更新間隔
-	renderer->SetRefreshInterval(33_msec);
+	// 更新間隔 [msec]
+	renderer->SetRefreshInterval(33);
 
 	// 最初に一度描画
 	Refresh();
