@@ -20,7 +20,4 @@ class WXROMWindow : public WXSubWindow
  public:
 	explicit WXROMWindow(wxWindow *parent);
 	~WXROMWindow() override;
-
- private:
-	WXTextScreen *panel {};
 };
