@@ -25,6 +25,9 @@ class WXScrollBar : public WXTextPanel
 	void FontChanged() override;
 	void Fit() override;
 
+	void SetScrollParam(int thumbsize_, int range_, int pagesize_) {
+		SetScrollParam(GetThumbPosition(), thumbsize_, range_, pagesize_);
+	}
 	void SetScrollParam(int pos_, int thumbsize_, int range_, int pagesize_);
 
 	bool SetThumbPosition(int pos_);
