@@ -12,7 +12,6 @@
 
 #include "wxnono.h"
 #include "uimessage.h"
-#include <array>
 
 wxDECLARE_EVENT(NONO_EVT_UIMESSAGE, wxCommandEvent);
 
@@ -20,21 +19,17 @@ class WXUIMessage
 {
  public:
 	// VM からの UIMessage を wxWidgets のイベントハンドラに接続する
-	static void Connect(UIMessage::ID id, wxEvtHandler *dest,
+	static void Connect(UIMessage::ID id, wxEvtHandler *win,
 		wxObjectEventFunction function);
 
 	// イベントハンドラの接続を解除する
-	static void Disconnect(UIMessage::ID id, wxEvtHandler *dest,
+	static void Disconnect(UIMessage::ID id, wxEvtHandler *win,
 		wxObjectEventFunction function);
 
-	// UIMessage を処理する
-	// (VM スレッドで実行される)
-	static void Process(UIMessage::Queue& queue);
+	// UIMessage のコールバック。
+	// (呼び出し元スレッドで実行される)
+	static void Process(uint id, int arg);
 
 	// すべてのハンドラが解除されているかチェックする (開発用)
 	static void AssertAllDisconnected();
-
- private:
-	static std::array< std::vector<wxEvtHandler *>, UIMessage::ID_MAX>
-		dest_table;
 };
