@@ -32,7 +32,7 @@ class HostInfoMonitor : public Object
 	Monitor *monitor {};
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	wxString osname {};
 	wxString machinename {};
